@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP.c
- * Version    : $Id: libipv6calc_db_wrapper_GeoIP.c,v 1.66 2014/07/30 20:31:43 ds6peter Exp $
- * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: libipv6calc_db_wrapper_GeoIP.c,v 1.72 2015/02/12 07:27:04 ds6peter Exp $
+ * Copyright  : 2013-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc GeoIP database wrapper
@@ -25,7 +25,12 @@
 
 #define GEOIP_WORKAROUND_NUM_DB_TYPES 1
 
-uint32_t wrapper_features_GeoIP = 0;
+#ifdef SUPPORT_GEOIP_DYN
+#define GEOIP_WORKAROUND_NUM_DB_TYPES_MAX 32
+#else
+#define GEOIP_WORKAROUND_NUM_DB_TYPES_MAX NUM_DB_TYPES
+#endif
+
 uint32_t lib_features_GeoIP = 0;
 
 char geoip_db_dir[NI_MAXHOST] = GEOIP_DB;
@@ -185,6 +190,9 @@ static uint32_t geoip_db_usage_map[GEOIP_DB_MAX_BLOCKS_32];
 
 char geoip_db_usage_string[NI_MAXHOST] = "";
 
+// local cache
+static GeoIP *db_ptr_cache[GEOIP_WORKAROUND_NUM_DB_TYPES_MAX];
+
 /*
  * function initialise the GeoIP wrapper
  *
@@ -294,6 +302,10 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 		geoip_num_db_types = 11 + 1; // < 1.4.5
 	};
 
+	if (geoip_num_db_types > GEOIP_WORKAROUND_NUM_DB_TYPES_MAX) {
+		geoip_num_db_types = GEOIP_WORKAROUND_NUM_DB_TYPES_MAX;
+	};
+
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Estimation of minimum geoip_num_db_types: %d", geoip_num_db_types - 1);
 #else
 	geoip_num_db_types = 0; // TODO: call function, once provided via GeoIP API
@@ -339,27 +351,30 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 		exit(1);
 	};
 
+	// add features to implemented
+	wrapper_features_by_source_implemented[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_IPV4_TO_CC | IPV6CALC_DB_GEOIP_IPV4 | IPV6CALC_DB_IPV6_TO_CC | IPV6CALC_DB_GEOIP_IPV6 | IPV6CALC_DB_IPV4_TO_AS | IPV6CALC_DB_IPV6_TO_AS | IPV6CALC_DB_IPV4_TO_CITY | IPV6CALC_DB_IPV6_TO_CITY | IPV6CALC_DB_IPV4_TO_REGION | IPV6CALC_DB_IPV6_TO_REGION | IPV6CALC_DB_IPV4_TO_COUNTRY | IPV6CALC_DB_IPV6_TO_COUNTRY;
+
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Check for standard GeoIP databases");
 
 	/* check required databases for resolution */
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_COUNTRY_EDITION) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_COUNTRY_EDITION available");
 		geoip_country_v4 = 1;
-		wrapper_features_GeoIP |= IPV6CALC_DB_IPV4_TO_CC | IPV6CALC_DB_GEOIP_IPV4;
+		wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_IPV4_TO_CC | IPV6CALC_DB_GEOIP_IPV4 | IPV6CALC_DB_IPV4_TO_COUNTRY;
 	};
 
 #ifdef SUPPORT_GEOIP_V6
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_COUNTRY_EDITION_V6) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_COUNTRY_EDITION_V6 available");
 		geoip_country_v6 = 1;
-		wrapper_features_GeoIP |= IPV6CALC_DB_IPV6_TO_CC | IPV6CALC_DB_GEOIP_IPV6;
+		wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_IPV6_TO_CC | IPV6CALC_DB_GEOIP_IPV6 | IPV6CALC_DB_IPV6_TO_COUNTRY;
 	};
 #endif
 
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_ASNUM_EDITION) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_ASNUM_EDITION available");
 		geoip_asnum_v4 = 1;
-		wrapper_features_GeoIP |= IPV6CALC_DB_IPV4_TO_AS | IPV6CALC_DB_GEOIP_IPV4;
+		wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_IPV4_TO_AS | IPV6CALC_DB_GEOIP_IPV4;
 	};
 
 	if ((lib_features_GeoIP & (GEOIP_LIB_FEATURE_IPV6_CC_BY_ADDR | GEOIP_LIB_FEATURE_IPV6_CN_BY_ADDR)) != 0) {
@@ -368,13 +383,13 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 		if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_ASNUM_EDITION_V6) == 1) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_ASNUM_EDITION_V6 available");
 			geoip_asnum_v6 = 1;
-			wrapper_features_GeoIP |= IPV6CALC_DB_IPV6_TO_AS | IPV6CALC_DB_GEOIP_IPV6;
+			wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_IPV6_TO_AS | IPV6CALC_DB_GEOIP_IPV6;
 		};
 
 		if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_CITY_EDITION_REV1_V6) == 1) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_CITY_EDITION_REV1_V6 available");
 			geoip_city_v6 = 1;
-			wrapper_features_GeoIP |= IPV6CALC_DB_GEOIP_IPV6;
+			wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_GEOIP_IPV6 | IPV6CALC_DB_IPV6_TO_CITY | IPV6CALC_DB_IPV6_TO_REGION;
 		};
 #else
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP check skipped for GEOIP_ASNUM_EDITION_V6 & GEOIP_CITY_EDITION_REV1_V6");
@@ -386,15 +401,50 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_init(void) {
 	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_CITY_EDITION_REV1) == 1) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_CITY_EDITION_REV1 available");
 		geoip_city_v4 = 1;
-		wrapper_features_GeoIP |= IPV6CALC_DB_GEOIP_IPV4;
+		wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_GEOIP_IPV4 | IPV6CALC_DB_IPV4_TO_CITY | IPV6CALC_DB_IPV4_TO_REGION;
 	};
 
-	wrapper_features |= wrapper_features_GeoIP;
+#ifdef SUPPORT_GEOIP_V6
+#ifdef GEOIP_CITY_EDITION_REV1_V6
+	if (libipv6calc_db_wrapper_GeoIP_db_avail(GEOIP_CITY_EDITION_REV1_V6) == 1) {
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "GeoIP database GEOIP_CITY_EDITION_REV1_V6 available");
+		geoip_city_v4 = 1;
+		wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] |= IPV6CALC_DB_GEOIP_IPV6 | IPV6CALC_DB_IPV6_TO_CITY | IPV6CALC_DB_IPV6_TO_REGION;
+	};
+#endif // GEOIP_CITY_EDITION_REV1_V6
+#endif // SUPPORT_GEOIP_V6
+
+	wrapper_features |= wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP];
 
 	return 0;
 };
 
 
+#ifdef SUPPORT_GEOIP
+/*
+ * function GeoIP_close
+ */
+static int libipv6calc_db_wrapper_GeoIP_close(GeoIP *gi) {
+	int i;
+
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Called");
+
+	if (gi != NULL) {
+		/* cleanup cache entry */
+		for (i = 0; i < GEOIP_WORKAROUND_NUM_DB_TYPES_MAX; i++) {
+			if (db_ptr_cache[i] == gi) {
+				db_ptr_cache[i] = NULL;
+			};
+		};
+
+		libipv6calc_db_wrapper_GeoIP_delete(gi);
+	};
+
+	return(0);
+};
+#endif // SUPPORT_GEOIP
+
+
 /*
  * function cleanup the GeoIP wrapper
  *
@@ -405,6 +455,15 @@ int libipv6calc_db_wrapper_GeoIP_wrapper_cleanup(void) {
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Called");
 
 #ifdef SUPPORT_GEOIP
+	int i;
+
+	for (i = 0; i < GEOIP_WORKAROUND_NUM_DB_TYPES_MAX; i++) {
+		if (db_ptr_cache[i] != NULL) {
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Close GeoIP: type=%d", i);
+			libipv6calc_db_wrapper_GeoIP_close(db_ptr_cache[i]);
+		};
+	};
+
 	libipv6calc_db_wrapper_GeoIP_cleanup();
 #endif
 
@@ -451,7 +510,7 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Called");
 
-	printf("%sGeoIP: features: 0x%08x\n", prefix, wrapper_features_GeoIP);
+	IPV6CALC_DB_FEATURE_INFO(prefix, IPV6CALC_DB_SOURCE_GEOIP)
 
 #ifdef SUPPORT_GEOIP
 
@@ -486,7 +545,6 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 			} else {
 				count++;
 				printf("%sGeoIP: %-33s:[%2d] %-40s (%s)\n", prefix, libipv6calc_db_wrapper_GeoIPDBDescription[i], i, (*libipv6calc_db_wrapper_GeoIPDBFileName_ptr)[i], libipv6calc_db_wrapper_GeoIP_database_info(gi));
-				libipv6calc_db_wrapper_GeoIP_delete(gi);
 			};
 		} else {
 			if (geoip_num_db_types > 0) {
@@ -524,10 +582,12 @@ void libipv6calc_db_wrapper_GeoIP_wrapper_print_db_info(const int level_verbose,
 
 #ifdef SUPPORT_GEOIP
 
+
 /*******************************
  * Wrapper functions for GeoIP
  *******************************/
 
+
 /*
  * function cleanup the GeoIP wrapper
  *
@@ -615,6 +675,8 @@ const char *libipv6calc_db_wrapper_GeoIP_lib_version(void) {
 			goto END_libipv6calc_db_wrapper;
 		};
 
+		dlerror();    /* Clear any existing error */
+
 		result_GeoIP_lib_version = (*dl_GeoIP_lib_version.func)();
 
 		if ((error = dlerror()) != NULL)  {
@@ -683,6 +745,8 @@ void libipv6calc_db_wrapper_GeoIP_setup_custom_directory(char *dir) {
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Call dl_GeoIP_setup_custom_directory: %s", dir);
 
+	dlerror();    /* Clear any existing error */
+
 	(*dl_GeoIP_setup_custom_directory.func)(dir);
 
 	if ((error = dlerror()) != NULL)  {
@@ -765,6 +829,8 @@ int libipv6calc_db_wrapper_GeoIP_db_avail(int type) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_db_avail = (*dl_GeoIP_db_avail.func)(type);
 
 	if ((error = dlerror()) != NULL)  {
@@ -812,6 +878,14 @@ GeoIP *libipv6calc_db_wrapper_GeoIP_open_type(int type, int flags) {
 		return(NULL);
 	};
 
+	if (db_ptr_cache[type] != NULL) {
+		// already open
+		gi = db_ptr_cache[type];
+
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Database already opened (cached) gi=%p type=%d", gi, type);
+		goto END_libipv6calc_db_wrapper;
+	};
+
 #ifdef SUPPORT_GEOIP_DYN
 	const char *dl_symbol = "GeoIP_open_type";
 	char *error;
@@ -844,18 +918,28 @@ GeoIP *libipv6calc_db_wrapper_GeoIP_open_type(int type, int flags) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	gi = (*dl_GeoIP_open_type.func)(type, flags);
 
 	if ((error = dlerror()) != NULL)  {
 		NONQUIETPRINT_WA("%s", error);
 		goto END_libipv6calc_db_wrapper;
 	};
-
-END_libipv6calc_db_wrapper:
 #else
 	gi = GeoIP_open_type(type, GEOIP_STANDARD);
 #endif
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Result: gi returned pointer: %s", (gi != NULL) ? "successful" : "NULL");
+
+	if (gi == NULL) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Database can't be openend type=%d", type);
+		goto END_libipv6calc_db_wrapper;
+	};
+
+	// fill cache
+	db_ptr_cache[type] = gi;
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Database successfully opened (fill-cache), gi=%p type=%d", gi, type)
+
+END_libipv6calc_db_wrapper:
 	return(gi);
 };
 
@@ -899,6 +983,8 @@ GeoIP* libipv6calc_db_wrapper_GeoIP_open(const char * filename, int flags) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	gi = (*dl_GeoIP_open.func)(filename, flags);
 
 	if ((error = dlerror()) != NULL)  {
@@ -953,6 +1039,8 @@ unsigned char libipv6calc_db_wrapper_GeoIP_database_edition (GeoIP* gi) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_database_edition = (*dl_GeoIP_database_edition.func)(gi);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1007,6 +1095,8 @@ char *libipv6calc_db_wrapper_GeoIP_database_info(GeoIP *gi) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_database_info = (*dl_GeoIP_database_info.func)(gi);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1065,6 +1155,10 @@ char *libipv6calc_db_wrapper_GeoIP_wrapper_db_info_used(void) {
 void libipv6calc_db_wrapper_GeoIP_delete(GeoIP* gi) {
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Called: %s", wrapper_geoip_info);
 
+	if (gi == NULL) {
+		return;
+	};
+
 #ifdef SUPPORT_GEOIP_DYN
 	const char *dl_symbol = "GeoIP_delete";
 	char *error;
@@ -1097,6 +1191,8 @@ void libipv6calc_db_wrapper_GeoIP_delete(GeoIP* gi) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	(*dl_GeoIP_delete.func)(gi);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1152,6 +1248,8 @@ const char* libipv6calc_db_wrapper_GeoIP_country_code_by_addr (GeoIP* gi, const
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_country_code_by_addr = (*dl_GeoIP_country_code_by_addr.func)(gi, addr);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1206,6 +1304,8 @@ const char* libipv6calc_db_wrapper_GeoIP_country_name_by_addr (GeoIP* gi, const
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_country_name_by_addr = (*dl_GeoIP_country_name_by_addr.func)(gi, addr);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1260,6 +1360,8 @@ GeoIPRecord *libipv6calc_db_wrapper_GeoIP_record_by_addr(GeoIP *gi, const char *
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_record_by_addr = (*dl_GeoIP_record_by_addr.func)(gi, addr);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1314,6 +1416,8 @@ GeoIPRecord *libipv6calc_db_wrapper_GeoIP_record_by_addr_v6(GeoIP *gi, const cha
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_record_by_addr_v6 = (*dl_GeoIP_record_by_addr_v6.func)(gi, addr);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1368,6 +1472,8 @@ void libipv6calc_db_wrapper_GeoIPRecord_delete (GeoIPRecord *gir) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	(*dl_GeoIPRecord_delete.func)(gir);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1540,6 +1646,8 @@ char* libipv6calc_db_wrapper_GeoIP_name_by_addr (GeoIP* gi, const char *addr) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_name_by_addr = (*dl_GeoIP_name_by_addr.func)(gi, addr);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1595,6 +1703,8 @@ char* libipv6calc_db_wrapper_GeoIP_name_by_addr_v6 (GeoIP* gi, const char *addr)
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_GeoIP_name_by_addr_v6 = (*dl_GeoIP_name_by_addr_v6.func)(gi, addr);
 
 	if ((error = dlerror()) != NULL)  {
@@ -1826,7 +1936,7 @@ int libipv6calc_db_wrapper_GeoIP_has_features(uint32_t features) {
 	int result = -1;
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Called with feature value to test: 0x%08x",features);
 
-	if ((wrapper_features_GeoIP & features) == features) {
+	if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] & features) == features) {
 		result = 1;
 	} else {
 		result = 0;
@@ -1851,12 +1961,13 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_code_by_addr(const char
 		GeoIP_type = GEOIP_COUNTRY_EDITION_V6;
 #endif // SUPPORT_GEOIP_V6
 	} else {
-		return (NULL);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	gi = libipv6calc_db_wrapper_GeoIP_open_type(GeoIP_type, 0);
+
 	if (gi == NULL) {
-		return (NULL);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	if (proto == 4) {
@@ -1891,8 +2002,7 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_code_by_addr(const char
 	GEOIP_DB_USAGE_MAP_TAG(GeoIP_type);
 
 END_libipv6calc_db_wrapper:
-	libipv6calc_db_wrapper_GeoIP_delete(gi);
-
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Result for addr=%s proto=%d: %s", addr, proto, GeoIP_result_ptr);
 	return(GeoIP_result_ptr);
 };
 
@@ -1942,13 +2052,19 @@ const char *libipv6calc_db_wrapper_GeoIP_wrapper_country_name_by_addr(const char
 #endif // SUPPORT_GEOIP_V6
 	};
 
+	if (GeoIP_result_ptr == NULL) {
+		goto END_libipv6calc_db_wrapper;
+	};
+
+	if (strlen(GeoIP_result_ptr) == 0) {
+		GeoIP_result_ptr = NULL;
+		goto END_libipv6calc_db_wrapper;
+	};
+
 	GEOIP_DB_USAGE_MAP_TAG(GeoIP_type);
 
-#ifdef SUPPORT_GEOIP_V6
 END_libipv6calc_db_wrapper:
-#endif // SUPPORT_GEOIP_V6
-	libipv6calc_db_wrapper_GeoIP_delete(gi);
-
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Result for addr=%s proto=%d: %s", addr, proto, GeoIP_result_ptr);
 	return(GeoIP_result_ptr);
 };
 
@@ -1962,38 +2078,39 @@ char *libipv6calc_db_wrapper_GeoIP_wrapper_asnum_by_addr(const char *addr, const
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Called with addr=%s proto=%d", addr, proto);
 
 	if (proto == 4) {
-		if ((wrapper_features_GeoIP & IPV6CALC_DB_IPV4_TO_AS) == 0) {
+		if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] & IPV6CALC_DB_IPV4_TO_AS) == 0) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Database/Support not available: GEOIP_ASNUM_EDITION");
-			return(NULL);
+			goto END_libipv6calc_db_wrapper;
 		};
 
 #if HAVE_DECL_GEOIP_ASNUM_EDITION == 1
 		GeoIP_type = GEOIP_ASNUM_EDITION;
 #else
-		return(NULL);
+		goto END_libipv6calc_db_wrapper;
 #endif
 
 #ifdef SUPPORT_GEOIP_V6
 	} else if (proto == 6) {
-		if ((wrapper_features_GeoIP & IPV6CALC_DB_IPV6_TO_AS) == 0) {
+		if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] & IPV6CALC_DB_IPV6_TO_AS) == 0) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Database/Support not available: GEOIP_ASNUM_EDITION_V6");
-			return(NULL);
+			goto END_libipv6calc_db_wrapper;
 		};
 
 #if HAVE_DECL_GEOIP_ASNUM_EDITION_V6 == 1
 		GeoIP_type = GEOIP_ASNUM_EDITION_V6;
 #else
-		return(NULL);
+		goto END_libipv6calc_db_wrapper;
 #endif
 
 #endif // SUPPORT_GEOIP_V6
 	} else {
-		return(NULL);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	gi = libipv6calc_db_wrapper_GeoIP_open_type(GeoIP_type, 0);
+
 	if (gi == NULL) {
-		return(NULL);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	if (proto == 4) {
@@ -2011,8 +2128,7 @@ char *libipv6calc_db_wrapper_GeoIP_wrapper_asnum_by_addr(const char *addr, const
 	GEOIP_DB_USAGE_MAP_TAG(GeoIP_type);
 
 END_libipv6calc_db_wrapper:
-	libipv6calc_db_wrapper_GeoIP_delete(gi);
-
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP, "Result for addr=%s proto=%d: %s", addr, proto, GeoIP_result_ptr);
 	return(GeoIP_result_ptr);
 };
 
@@ -2061,8 +2177,6 @@ GeoIPRecord *libipv6calc_db_wrapper_GeoIP_wrapper_record_city_by_addr(const char
 	GEOIP_DB_USAGE_MAP_TAG(GeoIP_type);
 
 END_libipv6calc_db_wrapper:
-	libipv6calc_db_wrapper_GeoIP_delete(gi);
-
 	return(GeoIP_result_ptr);
 };
 
