@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_IP2Location.c
- * Version    : $Id: libipv6calc_db_wrapper_IP2Location.c,v 1.19 2014/07/31 06:20:35 ds6peter Exp $
- * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: libipv6calc_db_wrapper_IP2Location.c,v 1.24 2015/01/23 07:57:48 ds6peter Exp $
+ * Copyright  : 2013-2015 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc IP2Location database wrapper
@@ -36,9 +36,6 @@ char ip2location_db_dir[NI_MAXHOST] = IP2LOCATION_DB;
 #define makestr(x) #x
 #define xmakestr(x) makestr(x)
 
-
-uint32_t wrapper_features_IP2Location = 0;
-
 #ifdef SUPPORT_IP2LOCATION_DYN
 char ip2location_lib_file[NI_MAXHOST] = IP2LOCATION_DYN_LIB;
 
@@ -54,7 +51,7 @@ static union { dl_IP2Location_open_t func; void * obj; } dl_IP2Location_open;
 
 static int dl_status_IP2Location_close = IPV6CALC_DL_STATUS_UNKNOWN;
 //static uint32_t (*dl_IP2Location_close)(IP2Location *loc) = NULL;
-typedef uint32_t (*dl_IP2Location_close_t)(IP2Location *loc);
+typedef int (*dl_IP2Location_close_t)(IP2Location *loc);
 static union { dl_IP2Location_close_t func; void * obj; } dl_IP2Location_close;
 
 static int dl_status_IP2Location_get_country_short = IPV6CALC_DL_STATUS_UNKNOWN;
@@ -110,6 +107,8 @@ static uint32_t ip2location_db_usage_map[IP2LOCATION_DB_MAX_BLOCKS_32];
 
 char ip2location_db_usage_string[NI_MAXHOST] = "";
 
+// local cache
+static IP2Location *db_ptr_cache[MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc)];
 
 // local prototyping
 static char     *libipv6calc_db_wrapper_IP2Location_dbfilename(int type); 
@@ -124,10 +123,10 @@ static char     *libipv6calc_db_wrapper_IP2Location_dbfilename(int type);
 int libipv6calc_db_wrapper_IP2Location_wrapper_init(void) {
 	int i;
 
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called");
 
 #ifdef SUPPORT_IP2LOCATION_DYN
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Load library: %s", ip2location_lib_file);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Load library: %s", ip2location_lib_file);
 
 	dl_IP2Location_handle = dlopen(ip2location_lib_file, RTLD_NOW | RTLD_LOCAL);
 
@@ -138,7 +137,7 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_init(void) {
 		return(1);
 	};
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Loaded library successful: %s", ip2location_lib_file);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Loaded library successful: %s", ip2location_lib_file);
 #else
 	// nothing to set for the moment
 #endif
@@ -149,45 +148,98 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_init(void) {
 	// nothing to set for the moment
 #endif
 
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Check for standard IP2Location databases");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Check for standard IP2Location databases");
 
 	/* check available databases for resolution */
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc); i++) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "IP2Location database test for availability: %s", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].filename);
+		// add features to implemented
+		wrapper_features_by_source_implemented[IPV6CALC_DB_SOURCE_IP2LOCATION] |= libipv6calc_db_wrapper_IP2Location_db_file_desc[i].features;
+
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "IP2Location database test for availability: %s", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].filename);
 		if (libipv6calc_db_wrapper_IP2Location_db_avail(libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number) == 1) {
-			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "IP2Location database available: %s", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
-			wrapper_features_IP2Location |= libipv6calc_db_wrapper_IP2Location_db_file_desc[i].feature;
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "IP2Location database available: %s", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
+			wrapper_features_by_source[IPV6CALC_DB_SOURCE_IP2LOCATION] |= libipv6calc_db_wrapper_IP2Location_db_file_desc[i].features;
 		};
 	};
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Version of linked library: %s / IPv6 support: %s / custom directory: %s", libipv6calc_db_wrapper_IP2Location_lib_version(), libipv6calc_db_wrapper_IP2Location_IPv6_support[wrapper_ip2location_ipv6_support].token, ip2location_db_dir);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Version of linked library: %s / IPv6 support: %s / custom directory: %s", libipv6calc_db_wrapper_IP2Location_lib_version(), libipv6calc_db_wrapper_IP2Location_IPv6_support[wrapper_ip2location_ipv6_support].token, ip2location_db_dir);
 
-	wrapper_features |= wrapper_features_IP2Location;
+	wrapper_features |= wrapper_features_by_source[IPV6CALC_DB_SOURCE_IP2LOCATION];
 
 	return 0;
 };
 
 
 /*
- * function cleanup the IP2Location wrapper
- *
- * in : (nothing)
- * out: 0=ok, 1=error
+ * wrapper: IP2Location_close
  */
-int libipv6calc_db_wrapper_IP2Location_wrapper_cleanup(void) {
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
+int libipv6calc_db_wrapper_IP2Location_close(IP2Location *loc) {
+	int i;
+	int result = 0;
 
-#ifdef SUPPORT_IP2LOCATION
-	// no general cleanup provided
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s", wrapper_ip2location_info);
+
+	if (loc == NULL) {
+		return(0);
+	};
+
+#ifdef SUPPORT_IP2LOCATION_DYN
+	const char *dl_symbol = "IP2Location_close";
+	char *error;
+
+	if (dl_IP2Location_handle == NULL) {
+		fprintf(stderr, "dl_IP2Location handle not defined\n");
+		goto END_libipv6calc_db_wrapper;
+	};
+
+	if (dl_status_IP2Location_close == IPV6CALC_DL_STATUS_UNKNOWN) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Call dlsym: %s", dl_symbol);
+
+		dlerror();    /* Clear any existing error */
+
+		*(void **) (&dl_IP2Location_close.obj) = dlsym(dl_IP2Location_handle, dl_symbol);
+
+		if ((error = dlerror()) != NULL)  {
+			dl_status_IP2Location_close = IPV6CALC_DL_STATUS_ERROR;
+			fprintf(stderr, "%s\n", error);
+			goto END_libipv6calc_db_wrapper;
+		};
+
+		dl_status_IP2Location_close = IPV6CALC_DL_STATUS_OK;
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called dlsym successful: %s", dl_symbol);
+	} else if (dl_status_IP2Location_close == IPV6CALC_DL_STATUS_ERROR) {
+		/* already known issue */
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already failed: %s", dl_symbol);
+		goto END_libipv6calc_db_wrapper;
+	} else {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already successful: %s", dl_symbol);
+	};
+
+	dlerror();    /* Clear any existing error */
+
+	result = (*dl_IP2Location_close.func)(loc);
+
+	if ((error = dlerror()) != NULL)  {
+		fprintf(stderr, "%s\n", error);
+	};
+#else
+	result = IP2Location_close(loc);
 #endif
+	goto END_libipv6calc_db_wrapper; // dummy
 
-	dl_IP2Location_handle = NULL; // disable handle
+END_libipv6calc_db_wrapper:
+	/* cleanup cache entry */
+	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc); i++) {
+		if (db_ptr_cache[i] == loc) {
+			db_ptr_cache[i] = NULL;
+		};
+	};
 
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Finished");
-	return 0;
+	return(result);
 };
 
 
+
 /*
  * function info of IP2Location wrapper
  *
@@ -195,7 +247,7 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_cleanup(void) {
  * out: modified string;
  */
 void libipv6calc_db_wrapper_IP2Location_wrapper_info(char* string, const size_t size) {
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called");
 
 #ifdef SUPPORT_IP2LOCATION
 	snprintf(string, size, "IP2Location available databases: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", (wrapper_features & IPV6CALC_DB_IPV4_TO_CC) ? 1 : 0, (wrapper_features & IPV6CALC_DB_IPV6_TO_CC) ? 1 : 0, ip2location_asnum_v4, ip2location_asnum_v6, ip2location_city_v4, ip2location_city_v6);
@@ -203,7 +255,7 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_info(char* string, const size_t
 	snprintf(string, size, "No IP2Location support built-in");
 #endif
 
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Finished");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished");
 	return;
 };
 
@@ -222,9 +274,9 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_print_db_info(const int level_ve
 		prefix = prefix_string;
 	};
 
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called");
 
-	printf("%sIP2Location: features: 0x%08x\n", prefix, wrapper_features_IP2Location);
+	IPV6CALC_DB_FEATURE_INFO(prefix, IPV6CALC_DB_SOURCE_IP2LOCATION)
 
 #ifdef SUPPORT_IP2LOCATION
 	printf("%sIP2Location: info of available databases in directory: %s\n", prefix, ip2location_db_dir);
@@ -234,12 +286,12 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_print_db_info(const int level_ve
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 		if (dl_IP2Location_handle == NULL) {
-			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Check whether db file exists: %s", libipv6calc_db_wrapper_IP2Location_dbfilename(type));
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Check whether db file exists: %s", libipv6calc_db_wrapper_IP2Location_dbfilename(type));
 			if (access(libipv6calc_db_wrapper_IP2Location_dbfilename(type), R_OK) == 0) {
-				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "DB file exists: %s", libipv6calc_db_wrapper_IP2Location_dbfilename(type));
+				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "DB file exists: %s", libipv6calc_db_wrapper_IP2Location_dbfilename(type));
 				printf("%sIP2Location: %-27s: %-40s (LIBRARY-NOT-LOADED)\n", prefix, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description, libipv6calc_db_wrapper_IP2Location_dbfilename(type));
 			} else {
-				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "DB file doesn't exist or can't open: %s (%s)", libipv6calc_db_wrapper_IP2Location_dbfilename(type), strerror(errno));
+				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "DB file doesn't exist or can't open: %s (%s)", libipv6calc_db_wrapper_IP2Location_dbfilename(type), strerror(errno));
 				if (level_verbose == LEVEL_VERBOSE2) {
 					printf("%sIP2Location: %-27s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description, libipv6calc_db_wrapper_IP2Location_dbfilename(type), strerror(errno));
 				};
@@ -274,7 +326,7 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_print_db_info(const int level_ve
 	snprintf(string, size, "%sNo IP2Location support built-in", prefix);
 #endif // SUPPORT_IP2LOCATION
 
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Finished");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished");
 	return;
 };
 
@@ -319,7 +371,7 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_db_info_used(void) {
 #ifdef SUPPORT_IP2LOCATION
 
 /*******************************
- * Wrapper extensenion functions for IP2Location
+ * Wrapper extension functions for IP2Location
  * because of missing support in library itself
  *******************************/
 
@@ -327,7 +379,7 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_db_info_used(void) {
  * wrapper extension: IP2Location_lib_version
  */
 const char * libipv6calc_db_wrapper_IP2Location_lib_version(void) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s", wrapper_ip2location_info);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	const char *result_IP2Location_lib_version;
@@ -351,7 +403,7 @@ static char *libipv6calc_db_wrapper_IP2Location_dbfilename(int type) {
 	static char tempstring[NI_MAXHOST];
 	int  entry = -1, i;
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s type=%d", wrapper_ip2location_info, type);
 
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc); i++) {
 		if (libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number == type) {
@@ -366,7 +418,7 @@ static char *libipv6calc_db_wrapper_IP2Location_dbfilename(int type) {
 
 	snprintf(tempstring, sizeof(tempstring), "%s/%s", ip2location_db_dir, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].filename);
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Finished: %s type=%d has filename=%s", wrapper_ip2location_info, type, tempstring);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished: %s type=%d has filename=%s", wrapper_ip2location_info, type, tempstring);
 
 	return(tempstring);
 };
@@ -378,7 +430,7 @@ static char *libipv6calc_db_wrapper_IP2Location_dbfilename(int type) {
 const char *libipv6calc_db_wrapper_IP2Location_dbdescription(int type) {
 	int  entry = -1, i;
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s type=%d", wrapper_ip2location_info, type);
 
 	for (i = 0; i < sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc) / sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc[0]); i++) {
 		if (libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number == type) {
@@ -391,7 +443,7 @@ const char *libipv6calc_db_wrapper_IP2Location_dbdescription(int type) {
 		return("unknown");
 	};
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Finished: %s type=%d has description=%s", wrapper_ip2location_info, type, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished: %s type=%d has description=%s", wrapper_ip2location_info, type, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
 
 	return(libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
 };
@@ -405,7 +457,7 @@ int libipv6calc_db_wrapper_IP2Location_db_avail(int type) {
 	char *filename;
 	int r = 0;
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s type=%d", wrapper_ip2location_info, type);
 
 	filename = libipv6calc_db_wrapper_IP2Location_dbfilename(type);
 
@@ -416,9 +468,9 @@ int libipv6calc_db_wrapper_IP2Location_db_avail(int type) {
 	r = (access(filename, R_OK) == 0) ? 1:0;
 
 	if (r == 0) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Finished: %s type=%d (still unknown) (r=%d: %s)", wrapper_ip2location_info, type, r, strerror(errno));
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished: %s type=%d (still unknown) (r=%d: %s)", wrapper_ip2location_info, type, r, strerror(errno));
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Finished: %s type=%d (%s) (r=%d)", wrapper_ip2location_info, type, filename, r);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished: %s type=%d (%s) (r=%d)", wrapper_ip2location_info, type, filename, r);
 	};
 
 END_libipv6calc_db_wrapper:
@@ -430,10 +482,11 @@ END_libipv6calc_db_wrapper:
  * wrapper extension: IP2Location_open_type
  */
 IP2Location *libipv6calc_db_wrapper_IP2Location_open_type(int type) {
+	IP2Location *loc;
 	char *filename;
 	int  entry = -1, i;
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s type=%d", wrapper_ip2location_info, type);
 
 	for (i = 0; i < sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc) / sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc[0]); i++) {
 		if (libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number == type) {
@@ -446,13 +499,32 @@ IP2Location *libipv6calc_db_wrapper_IP2Location_open_type(int type) {
 		return(NULL);
 	};
 
-	filename = libipv6calc_db_wrapper_IP2Location_dbfilename(type);
+	if (db_ptr_cache[entry] != NULL) {
+		// already open
+		loc = db_ptr_cache[entry];
 
-	if (filename == NULL) {
-		return(NULL);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Database already opened (cached) loc=%p type=%d", loc, type);
+		goto END_libipv6calc_db_wrapper;
+	} else {
+		filename = libipv6calc_db_wrapper_IP2Location_dbfilename(type);
+
+		if (filename == NULL) {
+			return(NULL);
+		};
+
+		loc = libipv6calc_db_wrapper_IP2Location_open(filename);
+
+		if (loc == NULL) {
+			goto END_libipv6calc_db_wrapper;
+		};
+
+		db_ptr_cache[entry] = loc;
+
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Database successfully opened (fill-cache), loc=%p type=%d", loc, type);
 	};
 
-	return(libipv6calc_db_wrapper_IP2Location_open(filename));
+END_libipv6calc_db_wrapper:
+	return(loc);
 };
 
 
@@ -461,12 +533,11 @@ IP2Location *libipv6calc_db_wrapper_IP2Location_open_type(int type) {
  *******************************/
 
 
-
 /*
  * wrapper: IP2Location_open
  */
 IP2Location *libipv6calc_db_wrapper_IP2Location_open(char *db) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s filename=%s", wrapper_ip2location_info, db);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s filename=%s", wrapper_ip2location_info, db);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	IP2Location *loc = NULL;
@@ -479,7 +550,7 @@ IP2Location *libipv6calc_db_wrapper_IP2Location_open(char *db) {
 	};
 
 	if (dl_status_IP2Location_open == IPV6CALC_DL_STATUS_UNKNOWN) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -492,15 +563,17 @@ IP2Location *libipv6calc_db_wrapper_IP2Location_open(char *db) {
 		};
 
 		dl_status_IP2Location_open = IPV6CALC_DL_STATUS_OK;
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_open == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	loc = (*dl_IP2Location_open.func)(db);
 
 	if ((error = dlerror()) != NULL)  {
@@ -516,67 +589,13 @@ END_libipv6calc_db_wrapper:
 };
 
 
-/*
- * wrapper: IP2Location_close
- */
-uint32_t libipv6calc_db_wrapper_IP2Location_close(IP2Location *loc) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
-
-#ifdef SUPPORT_IP2LOCATION_DYN
-	uint32_t result = 0;
-	const char *dl_symbol = "IP2Location_close";
-	char *error;
-
-	if (dl_IP2Location_handle == NULL) {
-		fprintf(stderr, "dl_IP2Location handle not defined\n");
-		goto END_libipv6calc_db_wrapper;
-	};
-
-	if (dl_status_IP2Location_close == IPV6CALC_DL_STATUS_UNKNOWN) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
-
-		dlerror();    /* Clear any existing error */
-
-		*(void **) (&dl_IP2Location_close.obj) = dlsym(dl_IP2Location_handle, dl_symbol);
-
-		if ((error = dlerror()) != NULL)  {
-			dl_status_IP2Location_close = IPV6CALC_DL_STATUS_ERROR;
-			fprintf(stderr, "%s\n", error);
-			goto END_libipv6calc_db_wrapper;
-		};
-
-		dl_status_IP2Location_close = IPV6CALC_DL_STATUS_OK;
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
-	} else if (dl_status_IP2Location_close == IPV6CALC_DL_STATUS_ERROR) {
-		/* already known issue */
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
-		goto END_libipv6calc_db_wrapper;
-	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
-	};
-
-	result = (*dl_IP2Location_close.func)(loc);
-
-	if ((error = dlerror()) != NULL)  {
-		fprintf(stderr, "%s\n", error);
-		goto END_libipv6calc_db_wrapper;
-	};
-
-END_libipv6calc_db_wrapper:
-	return(result);
-#else
-	return(IP2Location_close(loc));
-#endif
-};
-
-
 /*
  * wrapper: IP2Location_database_info
  */
 char *libipv6calc_db_wrapper_IP2Location_database_info(IP2Location *loc) {
 	static char resultstring[NI_MAXHOST];
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s", wrapper_ip2location_info);
 
 	if (loc == NULL) {
 		snprintf(resultstring, sizeof(resultstring), "%s", "can't retrieve database information");
@@ -598,7 +617,7 @@ char *libipv6calc_db_wrapper_IP2Location_database_info(IP2Location *loc) {
  * wrapper: IP2Location_free_record
  */ 
 void libipv6calc_db_wrapper_IP2Location_free_record(IP2LocationRecord *record) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s", wrapper_ip2location_info);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	const char *dl_symbol = "IP2Location_free_record";
@@ -610,7 +629,7 @@ void libipv6calc_db_wrapper_IP2Location_free_record(IP2LocationRecord *record) {
 	};
 
 	if (dl_status_IP2Location_free_record == IPV6CALC_DL_STATUS_UNKNOWN) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -623,15 +642,17 @@ void libipv6calc_db_wrapper_IP2Location_free_record(IP2LocationRecord *record) {
 		};
 
 		dl_status_IP2Location_free_record = IPV6CALC_DL_STATUS_OK;
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_free_record == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	(*dl_IP2Location_free_record.func)(record);
 
 	if ((error = dlerror()) != NULL)  {
@@ -651,7 +672,7 @@ END_libipv6calc_db_wrapper:
  * wrapper: IP2Location_get_country_short
  */
 IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_short(IP2Location *loc, char *ip) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s ip=%s", wrapper_ip2location_info, ip);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s ip=%s", wrapper_ip2location_info, ip);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	IP2LocationRecord *result_IP2Location_get_country_short = NULL;
@@ -664,7 +685,7 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_short(IP2Locat
 	};
 
 	if (dl_status_IP2Location_get_country_long == IPV6CALC_DL_STATUS_UNKNOWN) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -677,15 +698,17 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_short(IP2Locat
 		};
 
 		dl_status_IP2Location_get_country_short = IPV6CALC_DL_STATUS_OK;
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_get_country_long == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_IP2Location_get_country_short = (*dl_IP2Location_get_country_short.func)(loc, ip);
 
 	if ((error = dlerror()) != NULL)  {
@@ -705,7 +728,7 @@ END_libipv6calc_db_wrapper:
  * wrapper: IP2Location_get_country_long
  */
 IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_long(IP2Location *loc, char *ip) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s ip=%s", wrapper_ip2location_info, ip);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s ip=%s", wrapper_ip2location_info, ip);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	IP2LocationRecord *result_IP2Location_get_country_long = NULL;
@@ -718,7 +741,7 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_long(IP2Locati
 	};
 
 	if (dl_status_IP2Location_get_country_long == IPV6CALC_DL_STATUS_UNKNOWN) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -732,15 +755,17 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_long(IP2Locati
 
 		dl_status_IP2Location_get_country_long = IPV6CALC_DL_STATUS_OK;
 
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_get_country_long == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_IP2Location_get_country_long = (*dl_IP2Location_get_country_long.func)(loc, ip);
 
 	if ((error = dlerror()) != NULL)  {
@@ -760,15 +785,16 @@ END_libipv6calc_db_wrapper:
  * wrapper: IP2Location_get_all
  */
 IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_all(IP2Location *loc, char *ip) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
+	IP2LocationRecord *result_IP2Location_get_all = NULL;
+
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called: %s with ip=%s", wrapper_ip2location_info, ip);
 
 	if (loc == NULL) {
-		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "loc==NULL, return NULL");
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "loc==NULL, return NULL");
 		return(NULL);
 	};
 
 #ifdef SUPPORT_IP2LOCATION_DYN
-	IP2LocationRecord *result_IP2Location_get_all = NULL;
 	const char *dl_symbol = "IP2Location_get_all";
 	char *error;
 
@@ -778,7 +804,7 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_all(IP2Location *loc,
 	};
 
 	if (dl_status_IP2Location_get_all == IPV6CALC_DL_STATUS_UNKNOWN) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -792,15 +818,17 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_all(IP2Location *loc,
 
 		dl_status_IP2Location_get_all = IPV6CALC_DL_STATUS_OK;
 
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_get_all == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
+	dlerror();    /* Clear any existing error */
+
 	result_IP2Location_get_all = (*dl_IP2Location_get_all.func)(loc, ip);
 
 	if ((error = dlerror()) != NULL)  {
@@ -809,10 +837,11 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_all(IP2Location *loc,
 	};
 
 END_libipv6calc_db_wrapper:
-	return(result_IP2Location_get_all);
 #else
-	return(IP2Location_get_all(loc, ip));
+	result_IP2Location_get_all = IP2Location_get_all(loc, ip);
 #endif
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished IP2Location_get_all=%p", result_IP2Location_get_all);
+	return(result_IP2Location_get_all);
 };
 
 
@@ -828,15 +857,15 @@ END_libipv6calc_db_wrapper:
 int libipv6calc_db_wrapper_IP2Location_has_features(uint32_t features) {
 	int result = -1;
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called with feature value to test: 0x%08x", features);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called with feature value to test: 0x%08x", features);
 
-	if ((wrapper_features_IP2Location & features) == features) {
+	if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_IP2LOCATION] & features) == features) {
 		result = 1;
 	} else {
 		result = 0;
 	};
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Return with result: %d", result);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Return with result: %d", result);
 	return(result);
 };
 
@@ -848,48 +877,52 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_country_code_by_addr(char *addr
 	int IP2Location_type = 0;
 	char *IP2Location_result_ptr = NULL;
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called with addr=%s proto=%d", addr, proto);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called with addr=%s proto=%d", addr, proto);
 
 	if (proto == 4) {
 		IP2Location_type = IP2LOCATION_DB_IP_COUNTRY;
 	} else if (proto == 6) {
 		IP2Location_type = IP2LOCATION_DB_IPV6_COUNTRY;
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Unsupported proto: %d", proto);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Unsupported proto: %d", proto);
 		goto END_libipv6calc_db_wrapper;
 	};
 
 	loc = libipv6calc_db_wrapper_IP2Location_open_type(IP2Location_type);
 
 	if (loc == NULL) {
-		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Error opening IP2Location by type");
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Error opening IP2Location by type");
 		goto END_libipv6calc_db_wrapper;
 	};
 
 	record = libipv6calc_db_wrapper_IP2Location_get_country_short(loc, addr);
 
 	if (record == NULL) {
-		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "libipv6calc_db_wrapper_IP2Location_get_country_short did not return a record");
-		goto END_libipv6calc_db_wrapper_close;
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "did not return a record");
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	IP2Location_result_ptr = record->country_short;
 
 	if (IP2Location_result_ptr == NULL) {
-		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "libipv6calc_db_wrapper_IP2Location_get_country_short did not contain a country_short code");
-		goto END_libipv6calc_db_wrapper_close;
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "did not contain a country_short code");
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	if (strlen(IP2Location_result_ptr) > 2) {
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "libipv6calc_db_wrapper_IP2Location_get_country_short did not return a proper country_short code (length > 2): %s", IP2Location_result_ptr);
-		goto END_libipv6calc_db_wrapper_close;
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "did not return a proper country_short code (length > 2): %s", IP2Location_result_ptr);
+		IP2Location_result_ptr = NULL;
+		goto END_libipv6calc_db_wrapper;
+	};
+
+	if ((strcmp(IP2Location_result_ptr, "-") == 0) || (strcmp(IP2Location_result_ptr, "??") == 0)) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "don't know country_short code: %s", IP2Location_result_ptr);
+		IP2Location_result_ptr = NULL;
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	IP2LOCATION_DB_USAGE_MAP_TAG(IP2Location_type);
 
-END_libipv6calc_db_wrapper_close:
-	libipv6calc_db_wrapper_IP2Location_close(loc);
-
 END_libipv6calc_db_wrapper:
 	return(IP2Location_result_ptr);
 };
@@ -900,9 +933,9 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_country_name_by_addr(char *addr
 	IP2LocationRecord *record;
 
 	int IP2Location_type = 0;
-	char *IP2Location_result_ptr;
+	char *IP2Location_result_ptr = NULL;
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called with addr=%s proto=%d", addr, proto);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called with addr=%s proto=%d", addr, proto);
 
 	if (proto == 4) {
 		IP2Location_type = IP2LOCATION_DB_IP_COUNTRY;
@@ -915,27 +948,63 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_country_name_by_addr(char *addr
 	loc = libipv6calc_db_wrapper_IP2Location_open_type(IP2Location_type);
 
 	if (loc == NULL) {
-		return (NULL);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	record = libipv6calc_db_wrapper_IP2Location_get_country_long(loc, addr);
 
 	if (record == NULL) {
-		return (NULL);
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "did not return a record");
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	IP2Location_result_ptr = record->country_long;
 
 	if (IP2Location_result_ptr == NULL) {
-		return (NULL);
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "did not return a country_long");
+		goto END_libipv6calc_db_wrapper;
+	};
+
+	if (strcmp(IP2Location_result_ptr, "-") == 0) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "don't know country_name: %s", IP2Location_result_ptr);
+		IP2Location_result_ptr = NULL;
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	IP2LOCATION_DB_USAGE_MAP_TAG(IP2Location_type);
 
-	libipv6calc_db_wrapper_IP2Location_close(loc);
-
+END_libipv6calc_db_wrapper:
 	return(IP2Location_result_ptr);
 };
 
 #endif
 #endif
+
+
+/*
+ * function cleanup the IP2Location wrapper
+ *
+ * in : (nothing)
+ * out: 0=ok, 1=error
+ */
+int libipv6calc_db_wrapper_IP2Location_wrapper_cleanup(void) {
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Called");
+
+#ifdef SUPPORT_IP2LOCATION
+	int i;
+
+	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc); i++) {
+		if (db_ptr_cache[i] != NULL) {
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Close IP2Location: type=%d desc='%s'", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
+			libipv6calc_db_wrapper_IP2Location_close(db_ptr_cache[i]);
+		};
+	};
+
+	dl_IP2Location_handle = NULL; // disable handle
+#endif
+
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Finished");
+	return 0;
+};
+
+
