@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_IP2Location.h
- * Version    : $Id: libipv6calc_db_wrapper_IP2Location.h,v 1.4 2014/07/20 10:28:40 ds6peter Exp $
+ * Version    : $Id: libipv6calc_db_wrapper_IP2Location.h,v 1.6 2014/09/13 21:15:08 ds6peter Exp $
  * Copyright  : 2013-2013 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -37,14 +37,6 @@
 #define IP2LOCATION_DB_IP_COUNTRY_REGION_CITY_ISP		259
 #define IP2LOCATION_DB_IP_COUNTRY_REGION_CITY_ISP_DOMAIN	260
 
-// database names and descriptions
-typedef struct {
-	const unsigned int number;
-	const char        *filename;
-	const char        *description;
-	const uint32_t     feature;
-} db_file_desc;
-
 /*@unused@*/ static const db_file_desc libipv6calc_db_wrapper_IP2Location_db_file_desc[] = {
 	{ IP2LOCATION_DB_IP_COUNTRY                , "IP-COUNTRY.BIN"                , "IPv4 Country"                , IPV6CALC_DB_IPV4_TO_CC | IPV6CALC_DB_IP2LOCATION_IPV4 },
 	{ IP2LOCATION_DB_IPV6_COUNTRY              , "IPV6-COUNTRY.BIN"              , "IPv6 Country"                , IPV6CALC_DB_IPV6_TO_CC | IPV6CALC_DB_IP2LOCATION_IPV6 },
@@ -93,7 +85,7 @@ extern int                libipv6calc_db_wrapper_IP2Location_db_avail(int type);
 extern const char        *libipv6calc_db_wrapper_IP2Location_lib_version(void);
 extern IP2Location       *libipv6calc_db_wrapper_IP2Location_open(char *db);
 extern IP2Location       *libipv6calc_db_wrapper_IP2Location_open_type(int type);
-extern uint32_t           libipv6calc_db_wrapper_IP2Location_close(IP2Location *loc);
+extern int                libipv6calc_db_wrapper_IP2Location_close(IP2Location *loc);
 extern IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_all(IP2Location *loc, char *ip);
 void                      libipv6calc_db_wrapper_IP2Location_free_record(IP2LocationRecord *record);
 
