@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc/ipv6calc
  * File       : ipv6calchelp_local.c
- * Version    : $Id: ipv6calchelp_local.c,v 1.4 2014/04/02 06:11:55 ds6peter Exp $
+ * Version    : $Id: ipv6calchelp_local.c,v 1.8 2014/07/31 06:20:35 ds6peter Exp $
  * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -30,17 +30,6 @@ void printversion(void) {
 
 	fprintf(stderr, "%s: version %s", PROGRAM_NAME, PACKAGE_VERSION);
 
-#ifdef SUPPORT_IP2LOCATION
-	fprintf(stderr, " IP2Location");
-#endif
-
-#ifdef SUPPORT_GEOIP
-	fprintf(stderr, " GeoIP");
-#ifdef SUPPORT_GEOIP_V6
-	fprintf(stderr, " GeoIPv6");
-#endif
-#endif
-
 	fprintf(stderr, " %s", resultstring);
 
 	if (feature_zeroize == 1) {
@@ -58,9 +47,28 @@ void printversion(void) {
 	fprintf(stderr, "\n");
 };
 
+void printversion_help(void) {
+	char resultstring[NI_MAXHOST] = "";
+
+	libipv6calc_db_wrapper_features(resultstring, sizeof(resultstring));
+
+	fprintf(stderr, "\n");
+
+	fprintf(stderr, "Explanation of available(+)/possible(-) feature tokens\n");
+
+	libipv6calc_db_wrapper_features_help();
+
+	fprintf(stderr, "%-22s%c %s\n", "ANON_ZEROISE", (feature_zeroize == 1)? '+' : '-', "Anonymization method 'zeroize'");
+	fprintf(stderr, "%-22s%c %s\n", "ANON_ANONYMIZE", (feature_anon == 1) ? '+' : '-', "Anonymization method 'anonymize'");
+	fprintf(stderr, "%-22s%c %s\n", "ANON_KEEP-TYPE-ASN-CC", (feature_kp == 1) ? '+' : '-', "Anonymization method 'keep-type-asn-cc'");
+
+	fprintf(stderr, "\n");
+};
+
 void printversion_verbose(int level_verbose) {
 	printversion();
 	fprintf(stderr, "\n");
+
 	ipv6calc_print_features_verbose(level_verbose);
 };
 
@@ -72,7 +80,9 @@ void ipv6calc_printinfo(void)  {
 	printversion();
 	printcopyright();
 	fprintf(stderr, "This program formats and calculates IPv6 addresses and can do many more tricky things\n");
-	fprintf(stderr, "See '%s -?|-h|--help or -v -v' for more details\n\n", PROGRAM_NAME);
+	fprintf(stderr, "See '%s -?|-h|--help for online help\n", PROGRAM_NAME);
+	fprintf(stderr, "See '%s -v|--version -?|-h|--help' for explanation of feature tokens\n", PROGRAM_NAME);
+	fprintf(stderr, "See '%s -vv or -vvv for more internal version/feature information\n\n", PROGRAM_NAME);
 };
 
 /* print global help */
@@ -83,11 +93,7 @@ void ipv6calc_printhelp(const struct option longopts[], const s_ipv6calc_longopt
 
 	fprintf(stderr, "This program formats and calculates IPv6/IPv4/MAC addresses and can do many more tricky things\n");
 
-	fprintf(stderr, "\n");
-
-	printhelp_common();
-
-	fprintf(stderr, "\n");
+	printhelp_common(IPV6CALC_HELP_ALL & (~(IPV6CALC_HELP_QUIET)));
 
 	fprintf(stderr, "  [-q|--quiet]               : be more quiet (auto-enabled in pipe mode)\n");
 	fprintf(stderr, "  [-f|--flush]               : flush each line in pipe mode\n");
