@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : showinfo.c
- * Version    : $Id: showinfo.c,v 1.116 2014/07/31 06:20:35 ds6peter Exp $
+ * Version    : $Id: showinfo.c,v 1.127 2014/10/25 12:47:10 ds6peter Exp $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
@@ -28,6 +28,9 @@
 #include "../databases/lib/libipv6calc_db_wrapper.h"
 #include "../databases/lib/libipv6calc_db_wrapper_GeoIP.h"
 #include "../databases/lib/libipv6calc_db_wrapper_IP2Location.h"
+#include "../databases/lib/libipv6calc_db_wrapper_DBIP.h"
+#include "../databases/lib/libipv6calc_db_wrapper_External.h"
+#include "../databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
 
 #ifdef SUPPORT_IP2LOCATION
 #include "IP2Location.h"
@@ -69,6 +72,7 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " IPV6_PREFIXLENGTH=ddd         : given prefix length\n");
 	fprintf(stderr, " IPV6_AS_NUM=...               : AS number of (anonymized) IPv6 address\n");
 	fprintf(stderr, " IPV6_COUNTRYCODE=...          : Country Code of (anonymized) IPv6 address\n");
+	fprintf(stderr, " IPV6_COUNTRYCODE_SOURCE=...   : Source of Country Code of IPv6 address\n");
 	fprintf(stderr, " IPV4=ddd.ddd.ddd.ddd          : native IPv4 address\n");
 	fprintf(stderr, " IPV4_ANON=ddd.ddd.ddd.ddd     : native anonymized IPv4 address\n");
 	fprintf(stderr, " IPV4_REGISTRY=...             : registry token of native IPv4 address\n");
@@ -79,6 +83,7 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " IPV4_SOURCE[...]=...          : source of IPv4 address\n");
 	fprintf(stderr, " IPV4_AS_NUM[...]=...          : AS number of (anonymized) IPv4 address\n");
 	fprintf(stderr, " IPV4_COUNTRYCODE[...]=...     : Country Code of (anonymized) IPv4 address\n");
+	fprintf(stderr, " IPV4_COUNTRYCODE_SOURCE[...]=...: Source of Country Code of (anonymized) IPv4 address\n");
 	fprintf(stderr, "  ISATAP|TEREDO-SERVER|TEREDO-CLIENT|6TO4|LINK-LOCAL-IID\n");
 	fprintf(stderr, " SLA=xxxx                      : an included SLA\n");
 	fprintf(stderr, " IID=xxxx:xxxx:xxxx:xxxx       : an included interface identifier\n");
@@ -102,7 +107,8 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " IP2LOCATION_LATITUDE=...      : Latitude of IP address\n");
 	fprintf(stderr, " IP2LOCATION_LONGITUDE=...     : Longitude of IP address\n");
 	fprintf(stderr, " IP2LOCATION_DOMAIN=...        : Domain of IP address\n");
-	fprintf(stderr, " IP2LOCATION_ZIPCODE=...       : Zip code of IP address\n");
+	fprintf(stderr, " IP2LOCATION_ZIPCODE=...       : ZIP code of IP address\n");
+	fprintf(stderr, " IP2LOCATION_AREACODE=...      : Area code of IP address\n");
 	fprintf(stderr, " IP2LOCATION_DATABASE_INFO=... : Information about the used databases\n");
 #endif
 #ifdef SUPPORT_GEOIP
@@ -113,8 +119,23 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " GEOIP_ZIPCODE=...             : Zip code of IP address\n");
 	fprintf(stderr, " GEOIP_LATITUDE=...            : Latitude of IP address\n");
 	fprintf(stderr, " GEOIP_LONGITUDE=...           : Longitude of IP address\n");
+	fprintf(stderr, " GEOIP_AREACODE=...            : Area code of IP address\n");
+	fprintf(stderr, " GEOIP_DMACODE=...             : DMA/Metro code of IP address\n");
 	fprintf(stderr, " GEOIP_AS_TEXT=...             : Autonomous System information\n");
 	fprintf(stderr, " GEOIP_DATABASE_INFO=...       : Information about the used databases\n");
+#endif
+#ifdef SUPPORT_DBIP
+	fprintf(stderr, " DBIP_COUNTRY_SHORT=.. .       : Country code of IP address\n");
+	fprintf(stderr, " DBIP_CITY=...                 : City of IP address\n");
+	fprintf(stderr, " DBIP_REGION=...               : Region of IP address\n");
+	fprintf(stderr, " DBIP_DATABASE_INFO=.. .       : Information about the used databases\n");
+#endif
+#ifdef SUPPORT_EXTERNAL
+	fprintf(stderr, " EXTERNAL_COUNTRY_SHORT=.. .   : Country code of IP address\n");
+	fprintf(stderr, " EXTERNAL_DATABASE_INFO=.. .   : Information about the used databases\n");
+#endif
+#ifdef SUPPORT_BUILTIN
+	fprintf(stderr, " BUILTIN_DATABASE_INFO=.. .    : Information about the used databases\n");
 #endif
 	fprintf(stderr, " IPV6CALC_NAME=name            : Name of ipv6calc\n");
 	fprintf(stderr, " IPV6CALC_VERSION=x.y          : Version of ipv6calc\n");
@@ -140,7 +161,7 @@ static void printfooter(const uint32_t formatoptions) {
 	char tempstring[NI_MAXHOST] = "";
 	char tempstring2[NI_MAXHOST] = "";
 
-#if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP
+#if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP || defined SUPPORT_DBIP || defined SUPPORT_EXTERNAL || defined SUPPORT_BUILTIN
 	char *string;
 #endif
 
@@ -161,6 +182,30 @@ static void printfooter(const uint32_t formatoptions) {
 		};
 #endif
 
+#ifdef SUPPORT_DBIP
+		string = libipv6calc_db_wrapper_DBIP_wrapper_db_info_used();
+		if ((string != NULL) && (strlen(string) > 0)) {
+			snprintf(tempstring, sizeof(tempstring), "DBIP_DATABASE_INFO=%s", string);
+			printout(tempstring);
+		};
+#endif
+
+#ifdef SUPPORT_EXTERNAL
+		string = libipv6calc_db_wrapper_External_wrapper_db_info_used();
+		if ((string != NULL) && (strlen(string) > 0)) {
+			snprintf(tempstring, sizeof(tempstring), "EXTERNAL_DATABASE_INFO=%s", string);
+			printout(tempstring);
+		};
+#endif
+
+#ifdef SUPPORT_BUILTIN
+		string = libipv6calc_db_wrapper_BuiltIn_wrapper_db_info_used();
+		if ((string != NULL) && (strlen(string) > 0)) {
+			snprintf(tempstring, sizeof(tempstring), "BUILTIN_DATABASE_INFO=%s", string);
+			printout(tempstring);
+		};
+#endif
+
 		snprintf(tempstring, sizeof(tempstring), "IPV6CALC_NAME=%s", PROGRAM_NAME);
 		printout(tempstring);
 		snprintf(tempstring, sizeof(tempstring), "IPV6CALC_VERSION=%s", PACKAGE_VERSION);
@@ -214,7 +259,7 @@ static void printfooter(const uint32_t formatoptions) {
 static void print_ip2location(char *addrstring, const uint32_t formatoptions, const char *additionalstring, int version) {
 	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
 
-	if (wrapper_features_IP2Location == 0) {
+	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_IP2LOCATION] == 0) {
 		DEBUGPRINT_NA(DEBUG_showinfo, "IP2Location support not active");
 		return;
 	};
@@ -225,7 +270,7 @@ static void print_ip2location(char *addrstring, const uint32_t formatoptions, co
 
 	uint32_t machinereadable = (formatoptions & FORMATOPTION_machinereadable);
 	char tempstring[NI_MAXHOST] = "";
-	char *CountryCode, *CountryName;
+	char *CountryCode = NULL, *CountryName = NULL;
 
 	DEBUGPRINT_WA(DEBUG_showinfo, "Called addrstring=%s formatoptions=0x%08x additionalstring=%s version=%d", addrstring, formatoptions, additionalstring, version);
 
@@ -259,9 +304,9 @@ static void print_ip2location(char *addrstring, const uint32_t formatoptions, co
 		};
 	} else {
 		if (strlen(additionalstring) > 0) {
-			snprintf(tempstring, sizeof(tempstring), "IP2Location reports for %s country %s (%s)", additionalstring, (CountryName != 0 ? CountryName : "UNKNOWN"), (CountryCode != NULL ? CountryCode : "??"));
+			snprintf(tempstring, sizeof(tempstring), "IP2Location reports for %s country %s (%s)", additionalstring, (CountryName != NULL ? CountryName : "UNKNOWN"), (CountryCode != NULL ? CountryCode : "??"));
 		} else {
-			snprintf(tempstring, sizeof(tempstring), "IP2Location country name and code: %s (%s)", (CountryName != 0 ? CountryName : "UNKNOWN"), (CountryCode != NULL ? CountryCode : "??"));
+			snprintf(tempstring, sizeof(tempstring), "IP2Location country name and code: %s (%s)", (CountryName != NULL ? CountryName : "UNKNOWN"), (CountryCode != NULL ? CountryCode : "??"));
 		};
 		printout(tempstring);
 	};
@@ -285,7 +330,7 @@ static void print_ip2location(char *addrstring, const uint32_t formatoptions, co
 
 	if (record != NULL) {
 		if ( machinereadable != 0 ) {
-#define TEST_IP2LOCATION_AVAILABLE(v)	((strstr(v, "unavailable") == NULL) && (strstr(v, "demo database") == NULL))
+#define TEST_IP2LOCATION_AVAILABLE(v)	((strstr(v, "unavailable") == NULL) && (strstr(v, "demo database") == NULL) && (strstr(v, "This is demo") == NULL))
 
 			if (TEST_IP2LOCATION_AVAILABLE(record->region)) {
 				snprintf(tempstring, sizeof(tempstring), "IP2LOCATION_REGION%s=%s", additionalstring, record->region);
@@ -320,6 +365,13 @@ static void print_ip2location(char *addrstring, const uint32_t formatoptions, co
 					printout(tempstring);
 				};
 			};
+
+			if (TEST_IP2LOCATION_AVAILABLE(record->areacode)) {
+				if (strcmp(record->areacode, "-") != 0) {
+					snprintf(tempstring, sizeof(tempstring), "IP2LOCATION_AREACODE%s=%s", additionalstring, record->areacode);
+					printout(tempstring);
+				};
+			};
 		} else {
 			fprintf(stdout, " IP2Location not machinereadable output currently only limited supported\n");
 		};
@@ -330,8 +382,6 @@ static void print_ip2location(char *addrstring, const uint32_t formatoptions, co
 			ERRORPRINT_WA("IP2Location returned no record for address: %s", addrstring);
 		};
 	};
-
-	libipv6calc_db_wrapper_IP2Location_close(IP2LocationObj);
 };
 #endif
 
@@ -340,7 +390,7 @@ static void print_ip2location(char *addrstring, const uint32_t formatoptions, co
 static void print_geoip(const char *addrstring, const uint32_t formatoptions, const char *additionalstring, int version) {
 	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
 
-	if (wrapper_features_GeoIP == 0) {
+	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] == 0) {
 		DEBUGPRINT_NA(DEBUG_showinfo, "GeoIP support not active");
 		return;
 	};
@@ -410,16 +460,24 @@ static void print_geoip(const char *addrstring, const uint32_t formatoptions, co
 				snprintf(tempstring, sizeof(tempstring), "GEOIP_ZIPCODE%s=%s", additionalstring, gir->postal_code);
 				printout(tempstring);
 			};
-			snprintf(tempstring, sizeof(tempstring), "GEOIP_LATITUDE%s=%f", additionalstring, gir->latitude);
-			printout(tempstring);
-			snprintf(tempstring, sizeof(tempstring), "GEOIP_LONGITUDE%s=%f", additionalstring, gir->longitude);
-			printout(tempstring);
-			/*
-			snprintf(tempstring, sizeof(tempstring), "GEOIP_DMACODE%s=%d", additionalstring, gir->dma_code);
-			printout(tempstring);
-			snprintf(tempstring, sizeof(tempstring), "GEOIP_AREACODE%s=%d", additionalstring, gir->area_code);
-			printout(tempstring);
-			*/
+			if ((gir->latitude != 0) && (gir->longitude != 0)) {
+				snprintf(tempstring, sizeof(tempstring), "GEOIP_LATITUDE%s=%f", additionalstring, gir->latitude);
+				printout(tempstring);
+				snprintf(tempstring, sizeof(tempstring), "GEOIP_LONGITUDE%s=%f", additionalstring, gir->longitude);
+				printout(tempstring);
+			};
+			if (gir->continent_code != NULL) {
+				snprintf(tempstring, sizeof(tempstring), "GEOIP_CONTINENTCODE%s=%s", additionalstring, gir->continent_code);
+				printout(tempstring);
+			};
+			if (gir->dma_code != 0) {
+				snprintf(tempstring, sizeof(tempstring), "GEOIP_DMACODE%s=%d", additionalstring, gir->dma_code);
+				printout(tempstring);
+			};
+			if (gir->area_code != 0) {
+				snprintf(tempstring, sizeof(tempstring), "GEOIP_AREACODE%s=%d", additionalstring, gir->area_code);
+				printout(tempstring);
+			};
 		} else {
 			fprintf(stdout, " GeoIP not machinereadable output currently only limited supported\n");
 		};
@@ -428,6 +486,100 @@ static void print_geoip(const char *addrstring, const uint32_t formatoptions, co
 };
 #endif
 
+#ifdef SUPPORT_DBIP
+/* print DBIP information */
+static void print_dbip(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatoptions, const char *additionalstring) {
+	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
+
+	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_DBIP] == 0) {
+		DEBUGPRINT_NA(DEBUG_showinfo, "DBIP support not active");
+		return;
+	};
+
+	int ret;
+
+	char returnedCountry[256] = "";
+	char returnedCity[256] = "";
+	char returnedRegion[256] = "";
+
+	uint32_t machinereadable = (formatoptions & FORMATOPTION_machinereadable);
+	char tempstring[NI_MAXHOST] = "";
+
+	ret = libipv6calc_db_wrapper_DBIP_wrapper_country_code_by_addr(ipaddrp, returnedCountry, sizeof(returnedCountry));
+	if ((ret == 0) && (strlen(returnedCountry) > 0)) {
+		DEBUGPRINT_WA(DEBUG_showinfo, "DBIP IPv%d country database result", ipaddrp->proto);
+
+		if ( machinereadable != 0 ) {
+			snprintf(tempstring, sizeof(tempstring), "DBIP_COUNTRY_SHORT%s=%s", additionalstring, returnedCountry);
+			printout(tempstring);
+		} else {
+			if (strlen(additionalstring) > 0) {
+				fprintf(stdout, "DBIP country code for %s: %s\n", additionalstring, returnedCountry);
+			} else {
+				fprintf(stdout, "DBIP country code: %s\n", returnedCountry);
+			};
+		};
+	};
+
+	ret = libipv6calc_db_wrapper_DBIP_wrapper_city_by_addr(ipaddrp, returnedCity, sizeof(returnedCity), returnedRegion, sizeof(returnedRegion));
+	if ((ret == 0) && (strlen(returnedCity) > 0)) {
+		DEBUGPRINT_WA(DEBUG_showinfo, "DBIP IPv%d city database result", ipaddrp->proto);
+
+		if ( machinereadable != 0 ) {
+			snprintf(tempstring, sizeof(tempstring), "DBIP_CITY%s=%s", additionalstring, returnedCity);
+			printout(tempstring);
+		} else {
+			fprintf(stdout, " DBIP not machinereadable output currently only limited supported\n");
+		};
+	};
+
+	if ((returnedRegion != NULL) && (strlen(returnedRegion) > 0)) {
+		DEBUGPRINT_WA(DEBUG_showinfo, "DBIP IPv%d region database result", ipaddrp->proto);
+
+		if ( machinereadable != 0 ) {
+			snprintf(tempstring, sizeof(tempstring), "DBIP_REGION%s=%s", additionalstring, returnedRegion);
+			printout(tempstring);
+		} else {
+			fprintf(stdout, " DBIP not machinereadable output currently only limited supported\n");
+		};
+	};
+};
+#endif
+
+#ifdef SUPPORT_EXTERNAL
+/* print External DB information */
+static void print_external(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatoptions, const char *additionalstring) {
+	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
+
+	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_EXTERNAL] == 0) {
+		DEBUGPRINT_NA(DEBUG_showinfo, "External DB support not active");
+		return;
+	};
+
+	int ret;
+
+	char returnedCountry[256] = "";
+
+	uint32_t machinereadable = (formatoptions & FORMATOPTION_machinereadable);
+	char tempstring[NI_MAXHOST] = "";
+
+	ret = libipv6calc_db_wrapper_External_country_code_by_addr(ipaddrp, returnedCountry, sizeof(returnedCountry));
+	if ((ret == 0) && (strlen(returnedCountry) > 0)) {
+		DEBUGPRINT_WA(DEBUG_showinfo, "External IPv%d country database result", ipaddrp->proto);
+
+		if ( machinereadable != 0 ) {
+			snprintf(tempstring, sizeof(tempstring), "EXTERNAL_COUNTRY_SHORT%s=%s", additionalstring, returnedCountry);
+			printout(tempstring);
+		} else {
+			if (strlen(additionalstring) > 0) {
+				fprintf(stdout, "External DB country code for %s: %s\n", additionalstring, returnedCountry);
+			} else {
+				fprintf(stdout, "External DB country code: %s\n", returnedCountry);
+			};
+		};
+	};
+};
+#endif
 
 /* print IPv4 address */
 static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t formatoptions, const char *string) {
@@ -441,6 +593,9 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 	uint16_t cc_index = COUNTRYCODE_INDEX_UNKNOWN;
 	char *as_text = NULL;
 	int registry;
+	ipv6calc_ipaddr ipaddr;
+
+	unsigned int data_source = IPV6CALC_DB_SOURCE_UNKNOWN;
 
 	ipv4addr_anon_ptr = &ipv4addr_anon;
 
@@ -454,6 +609,8 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		return;
 	};
 
+	CONVERT_IPV4ADDRP_IPADDR(ipv4addrp, ipaddr);
+
 	if ((formatoptions & FORMATOPTION_printembedded) != 0) {
 		snprintf(embeddedipv4string, sizeof(embeddedipv4string), "[%s]", tempipv4string);
 	};
@@ -540,7 +697,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		as_num32 = libipv4addr_as_num32_by_addr(ipv4addrp);
 		if ((typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
 			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
-				as_text = libipv6calc_db_wrapper_as_text_by_addr(tempipv4string, 4);
+				as_text = libipv6calc_db_wrapper_as_text_by_addr(&ipaddr);
 			};
 		};
 
@@ -565,14 +722,28 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		};
 
 		/* get CountryCode Information */
-		cc_index = libipv4addr_cc_index_by_addr(ipv4addrp);
+		cc_index = libipv4addr_cc_index_by_addr(ipv4addrp, &data_source);
 
-		libipv6calc_db_wrapper_country_code_by_cc_index(tempstring2, sizeof(tempstring2),cc_index);
-		if ( machinereadable != 0 ) {
-			snprintf(tempstring, sizeof(tempstring), "IPV4_COUNTRYCODE%s=%s", embeddedipv4string, tempstring2);
-			printout(tempstring);
+		if (cc_index < COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN) {
+			libipv6calc_db_wrapper_country_code_by_cc_index(tempstring2, sizeof(tempstring2), cc_index);
+			if ( machinereadable != 0 ) {
+				snprintf(tempstring, sizeof(tempstring), "IPV4_COUNTRYCODE%s=%s", embeddedipv4string, tempstring2);
+				printout(tempstring);
+
+				if (data_source != IPV6CALC_DB_SOURCE_UNKNOWN) {
+					for (i = 0; i < MAXENTRIES_ARRAY(data_sources); i++ ) {
+						if (data_source == data_sources[i].number) {
+							snprintf(tempstring, sizeof(tempstring), "IPV4_COUNTRYCODE_SOURCE%s=%s" , embeddedipv4string, data_sources[i].name);
+							printout(tempstring);
+							break;
+						};
+					};
+				};
+			} else {
+				fprintf(stdout, "Country Code: %s\n", tempstring2);
+			};
 		} else {
-			fprintf(stdout, "Country Code: %s\n", tempstring2);
+			DEBUGPRINT_NA(DEBUG_showinfo, "Skip CountryCode print: cc_index>=COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN");
 		};
 	};
 
@@ -605,6 +776,16 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		/* GeoIP information */
 		print_geoip(tempipv4string, formatoptions, embeddedipv4string, 4);
 #endif
+
+#ifdef SUPPORT_DBIP
+		/* db-ip.com information */
+		print_dbip(&ipaddr, formatoptions, embeddedipv4string);
+#endif
+
+#ifdef SUPPORT_EXTERNAL
+		/* External DB information */
+		print_external(&ipaddr, formatoptions, embeddedipv4string);
+#endif
 	};
 
 	return;
@@ -800,6 +981,8 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	uint32_t machinereadable = ( formatoptions & FORMATOPTION_machinereadable);
 	uint32_t payload, as_num32, cc_index;
 	char *as_text = NULL;
+	unsigned int data_source = IPV6CALC_DB_SOURCE_UNKNOWN;
+	ipv6calc_ipaddr ipaddr;
 
 	ipv6addr_anon_ptr = &ipv6addr_anon;
 
@@ -826,6 +1009,8 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 	ipv6addrp->flag_prefixuse = flag_prefixuse;
 
+	CONVERT_IPV6ADDRP_IPADDR(ipv6addrp, ipaddr);
+
 	if ((typeinfo & (IPV6_ADDR_ANONYMIZED_PREFIX | IPV6_ADDR_ANONYMIZED_IID)) == 0 ) {
 		ipv6addr_copy(ipv6addr_anon_ptr, ipv6addrp); /* copy structure */
 
@@ -890,27 +1075,41 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	if ((typeinfo & (IPV6_NEW_ADDR_AGU)) != 0 ) {
 		/* CountryCode */
 		DEBUGPRINT_NA(DEBUG_showinfo, "get country code");
-		cc_index = libipv6addr_cc_index_by_addr(ipv6addrp);
+		cc_index = libipv6addr_cc_index_by_addr(ipv6addrp, &data_source);
 
 		if (cc_index > COUNTRYCODE_INDEX_MAX) {
 			if ( machinereadable != 0 ) {
 				fprintf(stderr, "Error getting CountryCode for IPv6 address\n");
 			};
 		} else {
-			libipv6calc_db_wrapper_country_code_by_cc_index(tempstring2, sizeof(tempstring2),cc_index);
-			if ( machinereadable != 0 ) {
-				snprintf(tempstring, sizeof(tempstring), "IPV6_COUNTRYCODE=%s" , tempstring2);
-				printout(tempstring);
+			if (cc_index < COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN) {
+				libipv6calc_db_wrapper_country_code_by_cc_index(tempstring2, sizeof(tempstring2),cc_index);
+				if ( machinereadable != 0 ) {
+					snprintf(tempstring, sizeof(tempstring), "IPV6_COUNTRYCODE=%s" , tempstring2);
+					printout(tempstring);
+
+					if (data_source != IPV6CALC_DB_SOURCE_UNKNOWN) {
+						for (i = 0; i < MAXENTRIES_ARRAY(data_sources); i++ ) {
+							if (data_source == data_sources[i].number) {
+								snprintf(tempstring, sizeof(tempstring), "IPV6_COUNTRYCODE_SOURCE=%s" , data_sources[i].name);
+								printout(tempstring);
+								break;
+							};
+						};
+					};
+				} else {
+					fprintf(stdout, "Country Code: %s\n", tempstring2);
+				};
 			} else {
-				fprintf(stdout, "Country Code: %s\n", tempstring2);
+				DEBUGPRINT_NA(DEBUG_showinfo, "Skip CountryCode print: cc_index>=COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN");
 			};
 		};
 
 		/* AS */
 		DEBUGPRINT_NA(DEBUG_showinfo, "get AS number/text");
 		if ((typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) == 0) {
-			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
-				as_text = libipv6calc_db_wrapper_as_text_by_addr(ipv6addrstring, 6);
+			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_AS) == 1) {
+				as_text = libipv6calc_db_wrapper_as_text_by_addr(&ipaddr);
 			};
 		};
 
@@ -919,21 +1118,25 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 		if ((as_num32 == 0) && (machinereadable == 0)) {
 			fprintf(stderr, "Error getting AS number from IPv6 address\n");
 		} else {
-			if ( machinereadable != 0 ) {
-				if (as_num32 == 0) {
-					snprintf(tempstring, sizeof(tempstring), "IPV6_AS_NUM=(unknown)");
-				} else {
-					snprintf(tempstring, sizeof(tempstring), "IPV6_AS_NUM=%d", as_num32);
-				};
-				printout(tempstring);
-
-				if (as_text != NULL) {
-					snprintf(tempstring, sizeof(tempstring), "IPV6_AS_TEXT=%s", as_text);
+			if (as_num32 != ASNUM_AS_UNKNOWN) {
+				if ( machinereadable != 0 ) {
+					if (as_num32 == 0) {
+						snprintf(tempstring, sizeof(tempstring), "IPV6_AS_NUM=(unknown)");
+					} else {
+						snprintf(tempstring, sizeof(tempstring), "IPV6_AS_NUM=%d", as_num32);
+					};
 					printout(tempstring);
-				};
 
+					if (as_text != NULL) {
+						snprintf(tempstring, sizeof(tempstring), "IPV6_AS_TEXT=%s", as_text);
+						printout(tempstring);
+					};
+
+				} else {
+					fprintf(stdout, "ASN for address: %d\n", as_num32);
+				};
 			} else {
-				fprintf(stdout, "ASN for address: %d\n", as_num32);
+				DEBUGPRINT_NA(DEBUG_showinfo, "Skip AS print: as_num32=ASNUM_AS_UNKNOWN");
 			};
 		};
 	};
@@ -1046,7 +1249,6 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 			fprintf(stdout, "Address type has SLA: %04x\n", (unsigned int) ipv6addr_getword(ipv6addrp, 3));
 		};
 	};
-	
 
 	/* Proper solicited node link-local multicast address? */
 	if ( (typeinfo & IPV6_NEW_ADDR_SOLICITED_NODE) != 0 ) {
@@ -1253,15 +1455,25 @@ END:
 	i = libipv6calc_db_wrapper_registry_num_by_ipv6addr(ipv6addrp);
 	if ((i != IPV6_ADDR_REGISTRY_RESERVED) && (i != IPV6_ADDR_REGISTRY_6BONE)) {
 		if ( ((typeinfo & IPV6_NEW_ADDR_AGU) != 0) && ((typeinfo & (IPV6_NEW_ADDR_TEREDO | IPV6_NEW_ADDR_ORCHID | IPV6_ADDR_ANONYMIZED_PREFIX)) == 0) ) {
-	#ifdef SUPPORT_IP2LOCATION
+#ifdef SUPPORT_IP2LOCATION
 			/* IP2Location information */
 			print_ip2location(ipv6addrstring, formatoptions, "", 6);
-	#endif
+#endif
 
-	#ifdef SUPPORT_GEOIP
+#ifdef SUPPORT_GEOIP
 			/* GeoIP information */
 			print_geoip(ipv6addrstring, formatoptions, "", 6);
-	#endif
+#endif
+
+#ifdef SUPPORT_DBIP
+			/* db-ip.com information */
+			print_dbip(&ipaddr, formatoptions, "");
+#endif
+
+#ifdef SUPPORT_EXTERNAL
+			/* External DB information */
+			print_external(&ipaddr, formatoptions, "");
+#endif
 		};
 	};
 
