@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_scenarios.sh
-# Version    : $Id: test_scenarios.sh,v 1.42 2014/06/16 20:31:01 ds6peter Exp $
+# Version    : $Id: test_scenarios.sh,v 1.46 2014/10/24 06:20:34 ds6peter Exp $
 # Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc (functions only)
@@ -80,7 +80,7 @@ testscenarios_ipv4_reserved() {
 169.253.255.255		noRFC
 169.254.0.0		RFC3927#1
 169.254.255.255		RFC3927#1
-169.255.0.0		noRFC
+169.255.0.0		noRFC		skip-anon-test
 172.15.255.255		noRFC
 172.16.0.0		RFC1918#3
 172.31.255.255		RFC1918#3
@@ -88,15 +88,15 @@ testscenarios_ipv4_reserved() {
 191.255.255.255		noRFC
 192.0.0.0		RFC5736#1
 192.0.0.255		RFC5736#1
-192.0.1.0		noRFC
-192.0.1.255		noRFC
+192.0.1.0		noRFC		skip-anon-test
+192.0.1.255		noRFC		skip-anon-test
 192.0.2.0		RFC5737#1
 192.0.2.255		RFC5737#1
 192.0.3.0		noRFC
 192.88.98.255		noRFC
 192.88.99.0		RFC3068#2.3
 192.88.99.255		RFC3068#2.3
-192.88.100.0		noRFC
+192.88.100.0		noRFC		skip-anon-test
 192.167.255.255		noRFC
 192.168.0.0		RFC1918#3
 192.168.255.255		RFC1918#3
@@ -108,7 +108,7 @@ testscenarios_ipv4_reserved() {
 198.51.99.255		noRFC
 198.51.100.0		RFC5737#3
 198.51.100.255		RFC5737#3
-198.51.101.0		noRFC
+198.51.101.0		noRFC		skip-anon-test
 203.0.112.255		noRFC
 203.0.113.0		RFC5737#3
 203.0.113.255		RFC5737#3
@@ -131,6 +131,9 @@ testscenarios_ipv6_reserved() {
 ::255.255.255.255	RFC4291#2.5.5.1
 ::ffff:0.0.0.0		RFC4291#2.5.5.2
 ::ffff:255.255.255.255	RFC4291#2.5.5.2
+0100::					RFC6666
+0100:0000:0000:0000:ffff:ffff:ffff:ffff	RFC6666
+0100:0000:0000:0001::			noRFC
 2001:0000::				RFC4380#6
 2001:0000:ffff:ffff:ffff:ffff:ffff:ffff	RFC4380#6
 2001:0010::				RFC4843#2
@@ -373,6 +376,8 @@ a909:16fa:9092:23ff:a909:4941::7	IPV6_REGISTRY=RIPENCC
 246.24.59.65				IPV4_COUNTRYCODE=AU
 ::246.24.59.65				IPV4_COUNTRYCODE[246.24.59.65]=AU
 ::ffff:246.24.59.65			IPV4_COUNTRYCODE[246.24.59.65]=AU
+2001:07fa:0:1::1			IPV6_REGISTRY=APNIC
+2001:07fa:0:0::1			IPV6_REGISTRY=RIPENCC
 END
 }
 
@@ -397,8 +402,32 @@ testscenarios_showinfo_ip2location() {
 46.244.223.233				IPV4_COUNTRYCODE=DE
 46.244.223.233				IP2LOCATION_COUNTRY_SHORT=DE
 # non-anonymized IPv6 prefix
+2001:4dd0:f838:a006::3			IPV6_COUNTRYCODE=DE
+2001:4dd0:f838:a006::3			IP2LOCATION_COUNTRY_SHORT=DE
+END
+}
+
+testscenarios_showinfo_DBIPv4() {
+	cat <<END | grep -v '^#'
+# match first valid entry in database
+1.0.0.0					IPV4_COUNTRYCODE=AU
+# match first entry in database
+223.255.255.255				IPV4_COUNTRYCODE=AU
+# non-anonymized IPv4 address
+46.244.223.233				IPV4_COUNTRYCODE=DE
+46.244.223.233				DBIP_COUNTRY_SHORT=DE
+END
+}
+
+testscenarios_showinfo_DBIPv6() {
+	cat <<END | grep -v '^#'
+# match first entry in database (db-ip.com assigns unusued range to US)
+2000:000:0000:0123:0123:4567:89ab:cdef	IPV6_COUNTRYCODE=US
+# match first entry in database (db-ip.com assigns unusued range to US)
+3fff:000:0000:0123:0123:4567:89ab:cdef	IPV6_COUNTRYCODE=US
+# non-anonymized IPv6 prefix
 2001:a60:113a:0123:0123:4567:89ab:cdef	IPV6_COUNTRYCODE=DE
-2001:a60:113a:0123:0123:4567:89ab:cdef	IP2LOCATION_COUNTRY_SHORT=DE
+2001:a60:113a:0123:0123:4567:89ab:cdef	DBIP_COUNTRY_SHORT=DE
 END
 }
 
