@@ -1,13 +1,18 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc_inttypes.h
- * Version    : $Id: ipv6calc_inttypes.h,v 1.1 2002/04/21 11:24:08 peter Exp $
- * Copyright  : 2002 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calc_inttypes.h,v 1.2 2014/10/07 20:25:23 ds6peter Exp $
+ * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Common header file to define inttypes like uint8_t and other basics
  */ 
 
+#ifndef _ipv6calc_inttypes_h
+
+#define _ipv6calc_inttypes_h 1
+
+
 #if defined(__linux__) 
 /* Linux/glibc has no inttypes.h */
 #include <stdint.h>
@@ -20,3 +25,8 @@
 
 /* max string length */
 #define NI_MAXHOST      1024
+#define IPV6CALC_ADDR_STRING_MAX	256
+#define IPV6CALC_SCOPEID_STRING_MAX	64
+
+
+#endif // _ipv6calc_inttypes_h
