@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: ipv6calchelp.c,v 1.64 2014/08/02 06:45:14 ds6peter Exp $
+ * Version    : $Id: ipv6calchelp.c,v 1.68 2014/09/24 09:07:57 ds6peter Exp $
  * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -22,7 +22,9 @@
 #include "databases/lib/libipv6calc_db_wrapper.h"
 #include "databases/lib/libipv6calc_db_wrapper_GeoIP.h"
 #include "databases/lib/libipv6calc_db_wrapper_IP2Location.h"
+#include "databases/lib/libipv6calc_db_wrapper_DBIP.h"
 #include "databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
+#include "databases/lib/libipv6calc_db_wrapper_External.h"
 
 
 #ifdef SUPPORT_IP2LOCATION
@@ -310,6 +312,7 @@ void printhelp_common(const uint32_t help_features) {
 	if ((help_features & IPV6CALC_HELP_IP2LOCATION) != 0) {
 #ifdef SUPPORT_IP2LOCATION
 		fprintf(stderr, "\n");
+		fprintf(stderr, "  [--disable-ip2location           ] : IP2Location support disabled\n");
 		fprintf(stderr, "  [--db-ip2location-disable        ] : IP2Location support disabled\n");
 		fprintf(stderr, "  [--db-ip2location-dir <directory>] : IP2Location database directory (default: %s)\n", ip2location_db_dir);
 #ifdef SUPPORT_IP2LOCATION_DYN
@@ -321,6 +324,7 @@ void printhelp_common(const uint32_t help_features) {
 	if ((help_features & IPV6CALC_HELP_GEOIP) != 0) {
 #ifdef SUPPORT_GEOIP
 		fprintf(stderr, "\n");
+		fprintf(stderr, "  [--disable-geoip                 ] : GeoIP support disabled\n");
 		fprintf(stderr, "  [--db-geoip-disable              ] : GeoIP support disabled\n");
 		fprintf(stderr, "  [--db-geoip-dir       <directory>] : GeoIP database directory (default: %s)\n", geoip_db_dir);
 #ifdef SUPPORT_GEOIP_DYN
@@ -329,6 +333,32 @@ void printhelp_common(const uint32_t help_features) {
 #endif
 	};
 
+	if ((help_features & IPV6CALC_HELP_DBIP) != 0) {
+#ifdef SUPPORT_DBIP
+		fprintf(stderr, "\n");
+		fprintf(stderr, "  [--disable-dbip                  ] : db-ip.com support disabled\n");
+		fprintf(stderr, "  [--db-dbip-disable               ] : db-ip.com support disabled\n");
+		fprintf(stderr, "  [--db-dbip-dir        <directory>] : db-ip.com database directory (default: %s)\n", dbip_db_dir);
+#endif
+	};
+
+	if ((help_features & IPV6CALC_HELP_EXTERNAL) != 0) {
+#ifdef SUPPORT_EXTERNAL
+		fprintf(stderr, "\n");
+		fprintf(stderr, "  [--disable-external              ] : External support disabled\n");
+		fprintf(stderr, "  [--db-external-disable           ] : External support disabled\n");
+		fprintf(stderr, "  [--db-external-dir    <directory>] : External database directory (default: %s)\n", external_db_dir);
+#endif
+	};
+
+	if ((help_features & IPV6CALC_HELP_BUILTIN) != 0) {
+#ifdef SUPPORT_BUILTIN
+		fprintf(stderr, "\n");
+		fprintf(stderr, "  [--disable-builtin               ] : BuiltIn support disabled\n");
+		fprintf(stderr, "  [--db-builtin-disable            ] : BuiltIn support disabled\n");
+#endif
+	};
+
 	fprintf(stderr, "\n");
 	return;
 };
@@ -422,6 +452,13 @@ static void printhelp_output_ipv6literal(void) {
 	fprintf(stderr, "   fe80::1%%0    -> fe80--1s0.ipv6-literal.net\n");
 };
 
+static void printhelp_output_hex(void) {
+	fprintf(stderr, " Print a given IPv4/v6 address in hex format depending on format options:\n");
+	fprintf(stderr, "  without any format option, e.g.\n");
+	fprintf(stderr, "   0123:4567:89ab:cdef:0000:1111:2222:3333 -> 0123456789abcdef0000111122223333\n");
+	fprintf(stderr, "   1.2.3.4                                 -> 01020304\n");
+};
+
 static void printhelp_output_eui64(void) {
 	fprintf(stderr, " Print a generated EUI-64 identifier, e.g.:\n");
 	fprintf(stderr, "  00:50:BF:06:B4:F5 -> 0250:bfff:fe06:b4f5\n");
@@ -556,6 +593,10 @@ void printhelp_output_dispatcher(const uint32_t outputtype) {
 		case FORMAT_octal:
 			printhelp_output_octal();
 			break;
+
+		case FORMAT_hex:
+			printhelp_output_hex();
+			break;
 			
 		default:
 			fprintf(stderr, " Examples currently missing...!\n");
@@ -629,7 +670,7 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			};
 			fprintf(stderr, "\n");
 
-			fprintf(stderr, "  Available presets (shortcut names) [--anonymize-preset PRESET-NAME]:\n");
+			fprintf(stderr, "  Available presets (shortcut names) [--anonymize-preset|ap PRESET-NAME]:\n");
 
 			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_set_list); i++) {
 				snprintf(method_name, sizeof(method_name), "%s", "unknown"); // default
