@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calcoptions.h
- * Version    : $Id: ipv6calcoptions_common.h,v 1.10 2014/07/30 20:31:43 ds6peter Exp $
+ * Version    : $Id: ipv6calcoptions_common.h,v 1.13 2014/09/24 09:07:58 ds6peter Exp $
  * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -40,13 +40,14 @@ static struct option ipv6calc_longopts_ip2location[] = {
 	{"db-ip2location-ipv6-default" , 0, NULL, DB_geoip_ipv6_default },
 
 	/* database options (new) */
+	{"disable-ip2location"         , 0, NULL, DB_ip2location_disable },
 	{"db-ip2location-disable"      , 0, NULL, DB_ip2location_disable },
 	{"db-ip2location-dir"          , 1, NULL, DB_ip2location_dir     },
 #ifdef SUPPORT_IP2LOCATION_DYN
 	{"db-ip2location-lib"          , 1, NULL, DB_ip2location_lib     },
-#endif
+#endif // SUPPORT_IP2LOCATION_DYN
 };
-#endif
+#endif // SUPPORT_IP2LOCATION
 
 #ifdef SUPPORT_GEOIP
 static char *ipv6calc_shortopts_geoip = "G";
@@ -61,14 +62,43 @@ static struct option ipv6calc_longopts_geoip[] = {
 	{"db-geoip-ipv6-default"       , 0, NULL, DB_geoip_ipv6_default },
 
 	/* database options (new) */
+	{"disable-geoip"               , 0, NULL, DB_geoip_disable       },
 	{"db-geoip-disable"            , 0, NULL, DB_geoip_disable       },
 	{"db-geoip-dir"                , 1, NULL, DB_geoip_dir           },
 #ifdef SUPPORT_GEOIP_DYN
 	{"db-geoip-lib"                , 1, NULL, DB_geoip_lib           },
-#endif
-};                
-#endif
+#endif // SUPPORT_GEOIP_DYN
+};
+#endif // SUPPORT_GEOIP
 
+#ifdef SUPPORT_DBIP
+static char *ipv6calc_shortopts_dbip = "";
+
+static struct option ipv6calc_longopts_dbip[] = {
+	{"disable-dbip"                , 0, NULL, DB_dbip_disable       },
+	{"db-dbip-disable"             , 0, NULL, DB_dbip_disable       },
+	{"db-dbip-dir"                 , 1, NULL, DB_dbip_dir           },
+};
+#endif // SUPPORT_DBIP
+
+#ifdef SUPPORT_EXTERNAL
+static char *ipv6calc_shortopts_external = "";
+
+static struct option ipv6calc_longopts_external[] = {
+	{"disable-external"            , 0, NULL, DB_external_disable   },
+	{"db-external-disable"         , 0, NULL, DB_external_disable   },
+	{"db-external-dir"             , 1, NULL, DB_external_dir       },
+};
+#endif // SUPPORT_EXTERNAL
+
+#ifdef SUPPORT_BUILTIN
+static char *ipv6calc_shortopts_builtin = "";
+
+static struct option ipv6calc_longopts_builtin[] = {
+	{"disable-builtin"             , 0, NULL, DB_builtin_disable    },
+	{"db-builtin-disable"          , 0, NULL, DB_builtin_disable    },
+};
+#endif // SUPPORT_BUILTIN
 
 /* define common anonymization short options */
 static char *ipv6calc_shortopts_common_anon = "";
@@ -79,6 +109,7 @@ static struct option ipv6calc_longopts_common_anon[] = {
 	{ "anonymize-careful"	, 0, NULL, CMD_ANON_PRESET_CAREFUL  },
 	{ "anonymize-paranoid"	, 0, NULL, CMD_ANON_PRESET_PARANOID },
 	{ "anonymize-preset"	, 1, NULL, CMD_ANON_PRESET_OPTION   },
+	{ "ap"			, 1, NULL, CMD_ANON_PRESET_OPTION   },
 	{ "anonymize-method"	, 1, NULL, CMD_ANON_METHOD_OPTION   },
 	{ "mask-ipv4"		, 1, NULL, CMD_ANON_MASK_IPV4 },
 	{ "mask-ipv6"		, 1, NULL, CMD_ANON_MASK_IPV6 },
