@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calctypes.h
- * Version    : $Id: ipv6calctypes.h,v 1.40 2014/04/25 06:30:19 ds6peter Exp $
+ * Version    : $Id: ipv6calctypes.h,v 1.43 2014/10/07 20:25:23 ds6peter Exp $
  * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -24,10 +24,16 @@ extern uint32_t ipv6calctypes_checkaction(const char *string);
 
 /* text representations for defines */
 typedef struct {
-	const uint32_t number;
+	const int number;
 	const char *token;
 } s_type;
 
+typedef struct {
+        const int number;
+        const char *token;
+        const char *tokensimple;
+} s_type2;
+
 
 /*
  * Format handling matrix for new address option style
@@ -237,6 +243,7 @@ typedef struct {
 	{ FORMAT_iid_token      , FORMATOPTION_printlowercase | FORMATOPTION_printuppercase },
 	{ FORMAT_octal          , FORMATOPTION_printfulluncompressed },
 	{ FORMAT_ipv6literal    , FORMATOPTION_machinereadable | FORMATOPTION_printlowercase | FORMATOPTION_printuppercase | FORMATOPTION_printcompressed | FORMATOPTION_printuncompressed | FORMATOPTION_printfulluncompressed },
+	{ FORMAT_hex            , FORMATOPTION_printuppercase | FORMATOPTION_printprefix | FORMATOPTION_printsuffix | FORMATOPTION_forceprefix },
 	{ FORMAT_prefix_mac     , FORMATOPTION_printlowercase | FORMATOPTION_printuppercase }
 };
 
@@ -316,4 +323,4 @@ typedef struct {
 	const char description[128];
 } s_ipv6calc_anon_methods;
 
-#endif
+#endif // _ipv6calctypes_h_
