@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv4addr.h
- * Version    : $Id: libipv4addr.h,v 1.36 2014/05/11 09:49:38 ds6peter Exp $
+ * Version    : $Id: libipv4addr.h,v 1.38 2014/09/24 09:07:58 ds6peter Exp $
  * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
@@ -82,7 +82,7 @@ typedef struct {
 #define IPV4_ADDR_REGISTRY_IANA		REGISTRY_IANA
 #define IPV4_ADDR_REGISTRY_APNIC	REGISTRY_APNIC
 #define IPV4_ADDR_REGISTRY_ARIN		REGISTRY_ARIN
-#define IPV4_ADDR_REGISTRY_RIPE		REGISTRY_RIPE
+#define IPV4_ADDR_REGISTRY_RIPENCC	REGISTRY_RIPENCC
 #define IPV4_ADDR_REGISTRY_LACNIC	REGISTRY_LACNIC
 #define IPV4_ADDR_REGISTRY_AFRINIC	REGISTRY_AFRINIC
 #define IPV4_ADDR_REGISTRY_RESERVED	REGISTRY_RESERVED
@@ -166,6 +166,6 @@ extern int ipv4addr_filter(const ipv6calc_ipv4addr *ipv4addrp, const s_ipv6calc_
 extern int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token);
 extern void ipv4addr_filter_clear(s_ipv6calc_filter_ipv4addr *filter);
 
-extern uint16_t libipv4addr_cc_index_by_addr(const ipv6calc_ipv4addr *ipv4addrp);
+extern uint16_t libipv4addr_cc_index_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsigned int *data_source_ptr);
 extern uint32_t libipv4addr_as_num32_by_addr(const ipv6calc_ipv4addr *ipv4addrp);
 extern int libipv4addr_registry_num_by_addr(const ipv6calc_ipv4addr *ipv4addrp);
