@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.c
- * Version    : $Id: libipv6addr.c,v 1.112 2014/07/22 06:00:41 ds6peter Exp $
+ * Version    : $Id: libipv6addr.c,v 1.115 2014/10/07 20:25:23 ds6peter Exp $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -1820,6 +1820,7 @@ int libipv6addr_to_octal(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring,
  */
 int libipv6addr_to_hex(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const size_t resultstring_length, const uint32_t formatoptions) {
 	int retval = 1;
+	int i;
 	char tempstring[NI_MAXHOST];
 
 	snprintf(tempstring, sizeof(tempstring), "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
@@ -1842,6 +1843,24 @@ int libipv6addr_to_hex(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, c
 		);
 
 	snprintf(resultstring, resultstring_length, "%s", tempstring);
+
+	if ((formatoptions & FORMATOPTION_printprefix) && (ipv6addrp->flag_prefixuse == 1)) {
+		// shorten string
+		resultstring[ipv6addrp->prefixlength / 4] = '\0';
+	} else if ((formatoptions & FORMATOPTION_printsuffix) && (ipv6addrp->flag_prefixuse == 1)) {
+		// move string
+		for (i = 0; i < 32 - (ipv6addrp->prefixlength / 4); i++) {
+			resultstring[i] = resultstring[i + (ipv6addrp->prefixlength / 4)];
+		};
+		resultstring[32 - (ipv6addrp->prefixlength / 4)] = '\0';
+	};
+
+	if (formatoptions & FORMATOPTION_printuppercase) {
+		for (i = 0; i < strlen(resultstring); i++) {
+			resultstring[i] = toupper(resultstring[i]);
+		};
+	};
+
 	retval = 0;	
 	return (retval);
 };
@@ -1925,7 +1944,6 @@ int libipv6addr_anonymize(ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_anon_se
 	uint32_t iid[2];
 	char tempstring[NI_MAXHOST];
 	char helpstring[NI_MAXHOST];
-	char resultstring[NI_MAXHOST];
 	int i, j, r;
 	int calculate_checksum = 0;
 	int calculate_checksum_prefix = 0;
@@ -1936,6 +1954,7 @@ int libipv6addr_anonymize(ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_anon_se
 	ipv6calc_macaddr   macaddr;
 	ipv6calc_eui64addr eui64addr;
 	ipv6calc_ipv4addr  ipv4addr;
+	ipv6calc_ipaddr    ipaddr;
 	uint32_t map_value;
 
 	uint16_t cc_index, flags;
@@ -2323,10 +2342,10 @@ int libipv6addr_anonymize(ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_anon_se
 				cc_index = COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN + IPV6_ADDR_REGISTRY_6BONE;
 				as_num32 = 0;
 			} else {
-				libipv6addr_ipv6addrstruct_to_uncompaddr(ipv6addrp, resultstring, sizeof(resultstring), 0);
+				CONVERT_IPV6ADDRP_IPADDR(ipv6addrp, ipaddr);
 
-				cc_index = libipv6calc_db_wrapper_cc_index_by_addr(resultstring, 6);
-				as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(resultstring, 6);
+				cc_index = libipv6calc_db_wrapper_cc_index_by_addr(&ipaddr, NULL);
+				as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr);
 
 				if (cc_index == COUNTRYCODE_INDEX_UNKNOWN) {
 					// on unknown country, map registry value
@@ -2615,10 +2634,10 @@ int libipv6addr_get_included_ipv4addr(const ipv6calc_ipv6addr *ipv6addrp, ipv6ca
  * in : *ipv6addrp = IPv6 address structure
  * out: country code index
  */
-uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
+uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp, unsigned int *data_source_ptr) {
 	uint32_t cc_index = COUNTRYCODE_INDEX_UNKNOWN;
 	ipv6calc_ipv4addr ipv4addr;
-	char tempipv6string[NI_MAXHOST] = "";
+	ipv6calc_ipaddr ipaddr;
 	int retval;
 
 	DEBUGPRINT_NA(DEBUG_libipv6addr, "start");
@@ -2639,7 +2658,7 @@ uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 					goto END_libipv6addr_cc_index_by_addr;
 				};
 
-				cc_index = libipv4addr_cc_index_by_addr(&ipv4addr);
+				cc_index = libipv4addr_cc_index_by_addr(&ipv4addr, NULL);
 			};
 		};
 	} else if (((ipv6addrp->scope & IPV6_ADDR_ANONYMIZED_IID) != 0) && ((ipv6addrp->scope & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_IID) != 0)) {
@@ -2649,7 +2668,7 @@ uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 			goto END_libipv6addr_cc_index_by_addr;
 		};
 
-		cc_index = libipv4addr_cc_index_by_addr(&ipv4addr);
+		cc_index = libipv4addr_cc_index_by_addr(&ipv4addr, data_source_ptr);
 	} else {
 		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_CC) == 1) {
 			if ((ipv6addrp->scope & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_IID) != 0) {
@@ -2660,7 +2679,7 @@ uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 					goto END_libipv6addr_cc_index_by_addr;
 				};
 
-				cc_index = libipv4addr_cc_index_by_addr(&ipv4addr);
+				cc_index = libipv4addr_cc_index_by_addr(&ipv4addr, data_source_ptr);
 			} else if ((ipv6addrp->scope & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX) != 0) {
 				retval = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 				if (retval != 0) {
@@ -2668,15 +2687,12 @@ uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 					goto END_libipv6addr_cc_index_by_addr;
 				};
 
-				cc_index = libipv4addr_cc_index_by_addr(&ipv4addr);
+				cc_index = libipv4addr_cc_index_by_addr(&ipv4addr, data_source_ptr);
+			} else if ((ipv6addrp->scope & IPV6_NEW_ADDR_6BONE) != 0) {
+				cc_index = COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN + IPV6_ADDR_REGISTRY_6BONE;
 			} else {
-				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(ipv6addrp, tempipv6string, sizeof(tempipv6string), FORMATOPTION_no_prefixlength);
-				if ( retval != 0 ) {
-					fprintf(stderr, "Error converting IPv6 address: %s\n", tempipv6string);
-					goto END_libipv6addr_cc_index_by_addr;
-				};
-
-				cc_index = libipv6calc_db_wrapper_cc_index_by_addr(tempipv6string, 6);
+				CONVERT_IPV6ADDRP_IPADDR(ipv6addrp, ipaddr);
+				cc_index = libipv6calc_db_wrapper_cc_index_by_addr(&ipaddr, data_source_ptr);
 			};
 		};
 	};
@@ -2696,7 +2712,7 @@ END_libipv6addr_cc_index_by_addr:
 uint32_t libipv6addr_as_num32_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 	uint32_t as_num32 = ASNUM_AS_UNKNOWN;
 	ipv6calc_ipv4addr ipv4addr;
-	char tempipv6string[NI_MAXHOST] = "";
+	ipv6calc_ipaddr ipaddr;
 	int retval;
 
 	DEBUGPRINT_NA(DEBUG_libipv6addr, "start");
@@ -2720,15 +2736,13 @@ uint32_t libipv6addr_as_num32_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 				as_num32 = libipv4addr_as_num32_by_addr(&ipv4addr);
 			};
 		};
+	} else if ((ipv6addrp->scope & IPV6_NEW_ADDR_6BONE) != 0) {
+		as_num32 = ASNUM_AS_UNKNOWN;
+		goto END_libipv6addr_as_num32_by_addr;
 	} else {
 		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
-			retval = libipv6addr_ipv6addrstruct_to_uncompaddr(ipv6addrp, tempipv6string, sizeof(tempipv6string), FORMATOPTION_no_prefixlength);
-			if ( retval != 0 ) {
-				fprintf(stderr, "Error converting IPv4 address: %s\n", tempipv6string);
-				goto END_libipv6addr_as_num32_by_addr;
-			};
-
-			as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(tempipv6string, 6);
+			CONVERT_IPV6ADDRP_IPADDR(ipv6addrp, ipaddr);
+			as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr);
 		};
 	};
 
@@ -2751,7 +2765,7 @@ int libipv6addr_registry_num_by_addr(const ipv6calc_ipv6addr *ipv6addrp) {
 	if (((ipv6addrp->scope & IPV6_ADDR_ANONYMIZED_PREFIX) != 0) \
 		&& ((ipv6addrp->scope & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX) == 0)) {
 			/* retrieve registry via cc_index from anonymized address (simple) */
-			cc_index = libipv6addr_cc_index_by_addr(ipv6addrp);
+			cc_index = libipv6addr_cc_index_by_addr(ipv6addrp, NULL);
 			registry = libipv6calc_db_wrapper_registry_num_by_cc_index(cc_index);
 	} else {
 		if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_REGISTRY) == 1) {
