@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.h
- * Version    : $Id: libipv6addr.h,v 1.81 2014/07/22 06:00:41 ds6peter Exp $
+ * Version    : $Id: libipv6addr.h,v 1.84 2014/10/07 20:25:23 ds6peter Exp $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -171,7 +171,7 @@ typedef struct {
 	uint8_t bit_end;		/* end of bit */
 	int flag_startend_use;		/* =1 start or end of bit in use */
 	int flag_valid;			/* address structure filled */
-	char scopeid[NI_MAXHOST];	/* scope ID value */
+	char scopeid[IPV6CALC_SCOPEID_STRING_MAX];	/* scope ID value */
 	int flag_scopeid;		/* =1: scope ID value set */
 } ipv6calc_ipv6addr;
 
@@ -332,24 +332,18 @@ typedef struct {
 #define IPV6_ADDR_REGISTRY_IANA		REGISTRY_IANA
 #define IPV6_ADDR_REGISTRY_APNIC	REGISTRY_APNIC
 #define IPV6_ADDR_REGISTRY_ARIN		REGISTRY_ARIN
-#define IPV6_ADDR_REGISTRY_RIPE		REGISTRY_RIPE
+#define IPV6_ADDR_REGISTRY_RIPENCC	REGISTRY_RIPENCC
 #define IPV6_ADDR_REGISTRY_LACNIC	REGISTRY_LACNIC
 #define IPV6_ADDR_REGISTRY_AFRINIC	REGISTRY_AFRINIC
 #define IPV6_ADDR_REGISTRY_RESERVED	REGISTRY_RESERVED
 #define IPV6_ADDR_REGISTRY_UNKNOWN	REGISTRY_UNKNOWN
 
-typedef struct {
-	const int number;
-	const char *token;
-	const char *tokensimple;
-} s_type2;
-
 /*@unused@*/ static const s_type2 ipv6calc_ipv6addrregistry[] = {
 	{ IPV6_ADDR_REGISTRY_6BONE	, "6BONE"	, "6BONE" 	},
 	{ IPV6_ADDR_REGISTRY_IANA	, "IANA"	, "IANA" 	},
 	{ IPV6_ADDR_REGISTRY_APNIC	, "APNIC"	, "APNIC" 	},
 	{ IPV6_ADDR_REGISTRY_ARIN	, "ARIN" 	, "ARIN"	},
-	{ IPV6_ADDR_REGISTRY_RIPE	, "RIPE NCC"	, "RIPENCC"	},
+	{ IPV6_ADDR_REGISTRY_RIPENCC	, "RIPE NCC"	, "RIPENCC"	},
 	{ IPV6_ADDR_REGISTRY_LACNIC	, "LACNIC"	, "LACNIC"	},
 	{ IPV6_ADDR_REGISTRY_AFRINIC	, "AFRINIC"	, "AFRINIC"	},
 	{ IPV6_ADDR_REGISTRY_RESERVED	, "reserved"	, "reserved"	},
@@ -400,6 +394,6 @@ extern void ipv6addr_filter_clear(s_ipv6calc_filter_ipv6addr *filter);
 
 extern int  libipv6addr_get_included_ipv4addr(const ipv6calc_ipv6addr *ipv6addrp, ipv6calc_ipv4addr *ipv4addrp, const int selector);
 
-extern uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp);
+extern uint16_t libipv6addr_cc_index_by_addr(const ipv6calc_ipv6addr *ipv6addrp, unsigned int *data_source_ptr);
 extern uint32_t libipv6addr_as_num32_by_addr(const ipv6calc_ipv6addr *ipv6addrp);
 extern int libipv6addr_registry_num_by_addr(const ipv6calc_ipv6addr *ipv6addrp);
