@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6calc.h
- * Version    : $Id: libipv6calc.h,v 1.25 2014/07/30 20:31:43 ds6peter Exp $
+ * Version    : $Id: libipv6calc.h,v 1.27 2014/10/07 20:25:23 ds6peter Exp $
  * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -12,6 +12,7 @@
 #include "ipv6calctypes.h"
 #include "libipv4addr.h"
 #include "libipv6addr.h"
+#include "libipaddr.h"
 #include "libmac.h"
 
 
@@ -48,7 +49,6 @@ typedef struct {
 
 /* Registries */
 #define REGISTRY_APNIC        0x02
-#define REGISTRY_RIPE         0x03
 #define REGISTRY_RIPENCC      0x03
 #define REGISTRY_LACNIC       0x04
 #define REGISTRY_AFRINIC      0x05
@@ -61,19 +61,22 @@ typedef struct {
 #define REGISTRY_UNKNOWN      0x0f
 
 // new array (try to remove old arrays)
-/*@unused@*/ static const s_type ipv6calc_registries[] = {
-        { REGISTRY_6BONE      , "6BONE"     },
-        { REGISTRY_IANA       , "IANA"      },
-        { REGISTRY_APNIC      , "APNIC"     },
-        { REGISTRY_ARIN       , "ARIN"      },
-        { REGISTRY_RIPE       , "RIPENCC"   },
-        { REGISTRY_LACNIC     , "LACNIC"    },
-        { REGISTRY_AFRINIC    , "AFRINIC"   },
-        { REGISTRY_6TO4       , "6TO4"      },
-        { REGISTRY_RESERVED   , "reserved"  },
-        { REGISTRY_UNKNOWN    , "unknown"   }
+/*@unused@*/ static const s_type2 ipv6calc_registries[] = {
+        { REGISTRY_6BONE      , "6BONE"     , "REGISTRY_6BONE"   },
+        { REGISTRY_IANA       , "IANA"      , "REGISTRY_IANA"    },
+        { REGISTRY_APNIC      , "APNIC"     , "REGISTRY_APNIC"   },
+        { REGISTRY_ARIN       , "ARIN"      , "REGISTRY_ARIN"    },
+        { REGISTRY_RIPENCC    , "RIPENCC"   , "REGISTRY_RIPENCC" },
+        { REGISTRY_LACNIC     , "LACNIC"    , "REGISTRY_LACNIC"  },
+        { REGISTRY_AFRINIC    , "AFRINIC"   , "REGISTRY_AFRINIC" },
+        { REGISTRY_6TO4       , "6TO4"      , "REGISTRY_6TO4"    },
+        { REGISTRY_RESERVED   , "reserved"  , "REGISTRY_RESERVED"},
+        { REGISTRY_UNKNOWN    , "unknown"   , "REGISTRY_UNKNOWN" }
 };
 
+/* some generic defines */
+#define IPV6CALC_PROTO_IPV4		4
+#define IPV6CALC_PROTO_IPV6		6
 
 /* some generic macros */
 
@@ -123,3 +126,5 @@ extern int   libipv6calc_anon_supported(const s_ipv6calc_anon_set *ipv6calc_anon
 
 extern const char *libipv6calc_registry_string_by_num(const int registry);
 
+extern int libipv6calc_bitcount_uint32_t(const uint32_t value);
+
